OC.L10N.register(
    "spreed",
    {
    "a conversation" : "яриа",
    "(Duration %s)" : "(Үргэлжлэх хугацаа %s)",
    "You attended a call with {user1}" : "Та {user1}-тай дуудлагад оролцлоо",
    "_%n guest_::_%n guests_" : ["%n зочин","%n зочин"],
    "You attended a call with {user1} and {user2}" : "Та {user1} болон {user2}-тай дуудлагад оролцлоо",
    "You attended a call with {user1}, {user2} and {user3}" : "Та {user1}, {user2} болон {user3}-тай дуудлагад оролцлоо",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Та {user1}, {user2}, {user3} болон {user4}-тай дуудлагад оролцлоо",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Та {user1}, {user2}, {user3}, {user4} болон {user5}-тай дуудлагад оролцлоо",
    "_%n other_::_%n others_" : ["%n бусад","%n бусад"],
    "{actor} invited you to {call}" : "{actor} таныг {call} руу урилаа",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Та <strong>яриа</strong>нд уригдсан эсвэл <strong>дуудлага</strong>д оролцсон",
    "Other activities" : "Бусад үйл ажиллагаа",
    "Talk" : "Talk",
    "Guest" : "–ó–æ—á–∏–Ω",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Nextcloud Talk-д тавтай морил!\nЭнэ яриан дотор Nextcloud Talk-д нэмэгдсэн шинэ боломжуудын талаар мэдээлэл авах болно.",
    "## New in Talk %s" : "## Talk %s-д шинээр",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge болон Safari хөтчүүдийг ашиглан аудио, видео дуудлагад оролцох боломжтой болсон",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Хоёр хүний яриа одоо тогтмол бөгөөд санамсаргүйгээр бүлгийн яриа болж хувирахгүй. Мөн нэг оролцогч яриаг орхисон ч яриа автоматаар устахгүй. Зөвхөн хоёр оролцогч хоёулаа орхивол серверээс устгагдана",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Та одоо чатад \"@all\" гэж бичээд бүх оролцогчдод мэдэгдэл илгээх боломжтой",
    "- With the \"arrow-up\" key you can repost your last message" : "- \"Дээш сум\" товчийг ашиглан сүүлийн мессежээ дахин илгээх боломжтой",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk одоо тушаалуудтай болсон, администратор тохируулсан эсэхийг шалгахын тулд чатад \"/help\" гэж бичээрэй",
    "- With projects you can create quick links between conversations, files and other items" : "- Төслүүдийн тусламжтай яриа, файл болон бусад зүйлсийн хооронд хурдан холбоос үүсгэх боломжтой",
    "- You can now mention guests in the chat" : "- Та одоо чатад зочдыг дурдаж болно",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Яриа одоо хүлээлгийн өрөөтэй байж болно. Энэ нь модераторуудад уулзалтад бэлтгэхийн тулд чат болон дуудлагад нэгдэх боломж олгох бөгөөд хэрэглэгчид болон зочид хүлээх шаардлагатай",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Та одоо мессежүүдэд шууд хариулж, бусад хэрэглэгчдэд таны мессеж юуны тухай болохыг ойлгуулах боломжтой",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Яриа болон оролцогчдыг хайхад одоо таны одоо байгаа яриануудыг мөн шүүх бөгөөд өмнөх яриануудыг олоход илүү хялбар болсон",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Circles апп суулгасан үед яриануудад хэрэглэгчийн тусгай бүлгүүд нэмэх боломжтой болсон",
    "- Check out the new grid and call view" : "- Шинэ торон болон дуудлагын харагдацыг үзээрэй",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Та одоо төхөөрөмжөөсөө файлуудыг шууд чат руу байршуулах эсвэл чирж хаях боломжтой",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Хуваалцсан файлууд одоо үзэгч аппуудын тусламжтай чатын харагдацын дотор шууд нээгддэг",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Та одоо дээд мөрний нэгдсэн хайлтаар чат болон мессежүүдийг хайх боломжтой",
    "- Spice up your messages with emojis from the emoji picker" : "- Эможи сонгогчоос эможи ашиглан мессежээ сайхан болго",
    "- You can now change your camera and microphone while being in a call" : "- Та одоо дуудлагын үеэр камер болон микрофоноо солих боломжтой",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Ярианд тайлбар нэмж контекст өгөөд, нэвтэрсэн хэрэглэгчид олж, өөрсдөө нэгдэх боломжтой болго",
    "- See a read status and send failed messages again" : "- Уншсан төлвийг харах ба илгээхэд алдаатай мессежүүдийг дахин илгээ",
    "- Raise your hand in a call with the R key" : "- R товчийг дарж дуудлагад гараа өргө",
    "- Join the same conversation and call from multiple devices" : "- Нэг яриа болон дуудлагад олон төхөөрөмжөөс нэгд",
    "- Send voice messages, share your location or contact details" : "- Дуут мессеж илгээ, байршил эсвэл холбоо барих мэдээллээ хуваалц",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Яриад бүлгүүд нэмээд, шинэ бүлгийн гишүүд автоматаар оролцогчоор нэмэгдэнэ",
    "- A preview of your audio and video is shown before joining a call" : "- Дуудлагад нэгдэхийн өмнө таны аудио болон видеоны урьдчилсан харагдац харуулагдана",
    "- You can now blur your background in the newly designed call view" : "- Та одоо шинэ загварын дуудлагын харагдацад арын дэвсгэрээ бүдэгрүүлж болно",
    "- Moderators can now assign general and individual permissions to participants" : "- Модераторууд одоо оролцогчдод ерөнхий болон хувийн зөвшөөрлүүд олгох боломжтой",
    "- You can now react to chat messages" : "- Та одоо чат мессежүүдэд хариу үйлдэл үзүүлж болно",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Хажуугийн самбараас хамгийн сүүлд хуваалцсан зүйлсийн тоймыг олох боломжтой болсон",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Бусдын санал бодлыг цуглуулах эсвэл огноо тохирохын тулд санал асуулга ашигла",
    "- Configure an expiration time for chat messages" : "- Чат мессежүүдийн дуусах хугацааг тохируул",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Том яриануудад бусдад мэдэгдэхгүйгээр дуудлага эхлүүлээрэй. Дуудлага эхэлсний дараа тус тусад нь дуудлагын мэдэгдэл илгээх боломжтой.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Яаралтай биш бол хүлээн авагчдад мэдэгдэхгүйгээр чат мессеж илгээ",
    "- Emojis can now be autocompleted by typing a \":\"" : "- \":\" бичиж эможи автоматаар гүйцээгдэх боломжтой болсон",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- \"/\" бичиж шинэ ухаалаг сонгогчийг ашиглан янз бүрийн зүйлсийг холбо",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Модераторууд одоо салангид өрөөнүүд үүсгэх боломжтой (Өндөр гүйцэтгэлтэй backend шаардлагатай)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Дуудлагуудыг одоо бичиж болно (Өндөр гүйцэтгэлтэй backend шаардлагатай)",
    "- Conversations can now have an avatar or emoji as icon" : "- Яриа одоо аватар эсвэл эможи дүрс тэмдэгтэй байж болно",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Видео дуудлагад бүдэг арын дэвсгэрээс гадна виртуал арын дэвсгэр одоо боломжтой болсон",
    "- Reactions are now available during calls" : "- Хариу үйлдэл дуудлагын үеэр одоо боломжтой",
    "- Typing indicators show which users are currently typing a message" : "- Бичиж байгаа заагч нь ямар хэрэглэгчид мессеж бичиж байгааг харуулна",
    "- Groups can now be mentioned in chats" : "- Бүлгүүдийг одоо чатад дурдах боломжтой",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Хэрэв хуулбарлах үйлчилгээ үзүүлэгч апп бүртгэгдсэн бол дуудлагын бичлэгүүд автоматаар хуулбарлагдана",
    "- Chat messages can be translated if a translation provider app is registered" : "- Хэрэв орчуулгын үйлчилгээ үзүүлэгч апп бүртгэгдсэн бол чат мессежүүдийг орчуулах боломжтой",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown**-ыг одоо _чат_ мессежүүдэд ашиглах боломжтой",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Бот хэрэгжүүлэхийн тулд Webhook одоо боломжтой болсон. Дэлгэрэнгүй мэдээллийг баримт бичгээс үзнэ үү https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Дараа нь дахин мэдэгдэл авахын тулд чат мессежид сануулга тавь",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- **Өөртөө тэмдэглэл** яриаг ашиглан тэмдэглэл хөтөлж, төхөөрөмжүүдийн хооронд мэдээлэл хуваалцаарай",
    "- Captions allow to send a message with a file at the same time" : "- Тайлбар нь файлтай хамт мессеж илгээх боломжийг олгодог",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Дэлгэц хуваалцаж байх үед илтгэгчийн видео одоо харагдах бөгөөд дуудлагын хариу үйлдлүүд хөдөлгөөнт болсон",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Нэвтэрсэн зохиогчид болон модераторууд мессежийг 6 цагийн турш засварлах боломжтой болсон",
    "- Unsent message drafts are now saved in your browser" : "- Илгээгээгүй мессежийн ноорог одоо таны хөтөчид хадгалагдана",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Текст чатыг одоо бусад Talk серверүүдтэй холбогдсон хэлбэрээр хийх боломжтой",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Модераторууд одоо бүртгэлүүд болон зочдыг яриад дахин нэгдэхээс сэргийлж хориглох боломжтой",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Холбогдсон календарын үйл явдлуудаас удахгүй болох дуудлагууд болон ажлаас гадуур орлогчдыг одоо яриануудад харуулдаг",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Дуудлагуудыг одоо бусад Talk серверүүдтэй холбогдсон хэлбэрээр хийх боломжтой (Өндөр гүйцэтгэлтэй backend шаардлагатай)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Windows, macOS болон Linux-д зориулсан Nextcloud Talk ширээний клиентийг танилцуулж байна: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Nextcloud Assistant-ийн тусламжтай дуудлагын бичлэгүүд болон уншаагүй мессежүүдийг нэгтгэн хураангуйла",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- И-мэйл хаягаар урьсан зочдыг таних, оролцогчдын жагсаалт импортлох, санал асуулгын ноорог болон дуудлагын оролцогчдын жагсаалт татах зэргээр уулзалтуудыг сайжруулсан",
    "- Archive conversations to stay focused" : "- Төвлөрөхийн тулд яриануудыг архивла",
    "- Schedule a meeting into your calendar from within a conversation" : "- Ярианы дотроос календартаа уулзалт товло",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Одоогийн ярианы мессежүүдийг баруун хажуугийн самбараас шууд хайх",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Шинэ шахмал жагсаалтаар илүү олон яриаг нэг харцаар харах (Talk тохиргооноос идэвхжүүлнэ үү)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Уулзалтын яриа одоо календараас гарчиг болон тайлбарыг синхрончилж, эхлэх цаг ойртох хүртэл хайлтын шүүлтүүрээр нуугдана",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Мэдэгдлийн тохиргоонд яриануудыг нууцлалтай гэж тэмдэглэж, ярианы жагсаалт болон мэдэгдлүүдээс мессежийн агуулгыг нуу",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- \"Бүү саад бол\" горимын үед push мэдэгдэл хүлээн авахын тулд яриануудыг чухал гэж тэмдэглэ",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Шинэ бүлгийн дуудлагыг шууд үүсгэхийн тулд хоёр хүний дуудлагад бусад оролцогчдыг нэм",
    "- Use threads to keep your chat and discussions organized" : "- Чат болон хэлэлцүүлгээ зохион байгуулалттай байлгахын тулд thread ашигла",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Дуудлагын үеэр шууд хуулбарлалт одоо боломжтой болсон (live-transcription ExApp болон Өндөр гүйцэтгэлтэй backend шаардлагатай)",
    "- Moderators can now pin messages so they are kept at the top" : "- Модераторууд зурвасуудыг дээд хэсэгт бэхлэх боломжтой болсон",
    "- Schedule a message to send it at a later time" : "- Зурвасыг дараа илгээхээр товлох",
    "_All %n participant_::_All %n participants_" : ["Бүх %n оролцогч","Бүх %n оролцогч"],
    "Reaction deleted by author" : "Хариу үйлдэл зохиогчоор устгагдсан",
    "{actor} created the conversation" : "{actor} яриаг үүсгэсэн",
    "You created the conversation" : "Та яриаг үүсгэсэн",
    "System created the conversation" : "Систем яриаг үүсгэсэн",
    "An administrator created the conversation" : "Администратор яриаг үүсгэсэн",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} ярианы нэрийг \"%1$s\"-аас \"%2$s\" болгон өөрчилсөн",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Та ярианы нэрийг \"%1$s\"-аас \"%2$s\" болгон өөрчилсөн",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Администратор ярианы нэрийг \"%1$s\"-аас \"%2$s\" болгон өөрчилсөн",
    "{actor} set the description" : "{actor} тайлбарыг тохируулсан",
    "You set the description" : "Та тайлбарыг тохируулсан",
    "An administrator set the description" : "Администратор тайлбарыг тохируулсан",
    "{actor} removed the description" : "{actor} тайлбарыг устгасан",
    "You removed the description" : "Та тайлбарыг устгасан",
    "An administrator removed the description" : "Администратор тайлбарыг устгасан",
    "You started a silent call" : "Та чимээгүй дуудлага эхлүүлсэн",
    "Outgoing silent call" : "Гарах чимээгүй дуудлага",
    "{actor} started a silent call" : "{actor} чимээгүй дуудлага эхлүүлсэн",
    "Incoming silent call" : "Ирж буй чимээгүй дуудлага",
    "You started a call" : "Та дуудлага эхлүүлсэн",
    "Outgoing call" : "Гарах дуудлага",
    "{actor} started a call" : "{actor} дуудлага эхлүүлсэн",
    "Incoming call" : "Ирж буй дуудлага",
    "{actor} joined the call" : "{actor} дуудлагад нэгдсэн",
    "You joined the call" : "Та дуудлагад нэгдсэн",
    "{actor} left the call" : "{actor} дуудлагаас гарсан",
    "You left the call" : "Та дуудлагаас гарсан",
    "{actor} unlocked the conversation" : "{actor} яриаг тайлсан",
    "You unlocked the conversation" : "Та яриаг тайлсан",
    "An administrator unlocked the conversation" : "Администратор яриаг тайлсан",
    "{actor} locked the conversation" : "{actor} яриаг түгжсэн",
    "You locked the conversation" : "Та яриаг түгжсэн",
    "An administrator locked the conversation" : "Администратор яриаг түгжсэн",
    "{actor} limited the conversation to the current participants" : "{actor} яриаг одоогийн оролцогчдоор хязгаарласан",
    "You limited the conversation to the current participants" : "Та яриаг одоогийн оролцогчдоор хязгаарласан",
    "An administrator limited the conversation to the current participants" : "Администратор яриаг одоогийн оролцогчдоор хязгаарласан",
    "{actor} opened the conversation to registered users" : "{actor} яриаг бүртгэлтэй хэрэглэгчдэд нээсэн",
    "You opened the conversation to registered users" : "Та яриаг бүртгэлтэй хэрэглэгчдэд нээсэн",
    "An administrator opened the conversation to registered users" : "Администратор яриаг бүртгэлтэй хэрэглэгчдэд нээсэн",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} яриаг бүртгэлтэй хэрэглэгчид болон Guests аппаар үүсгэсэн хэрэглэгчдэд нээсэн",
    "You opened the conversation to registered users and users created with the Guests app" : "Та яриаг бүртгэлтэй хэрэглэгчид болон Guests аппаар үүсгэсэн хэрэглэгчдэд нээсэн",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Администратор яриаг бүртгэлтэй хэрэглэгчид болон Guests аппаар үүсгэсэн хэрэглэгчдэд нээсэн",
    "The conversation is now open to everyone" : "Яриа одоо бүгдэд нээлттэй",
    "{actor} opened the conversation to everyone" : "{actor} яриаг бүгдэд нээсэн",
    "You opened the conversation to everyone" : "Та яриаг бүгдэд нээсэн",
    "{actor} restricted the conversation to moderators" : "{actor} яриаг модераторуудаар хязгаарласан",
    "You restricted the conversation to moderators" : "Та яриаг модераторуудаар хязгаарласан",
    "{actor} started breakout rooms" : "{actor} салангид өрөөнүүдийг эхлүүлсэн",
    "You started breakout rooms" : "Та салангид өрөөнүүдийг эхлүүлсэн",
    "{actor} stopped breakout rooms" : "{actor} салангид өрөөнүүдийг зогсоосон",
    "You stopped breakout rooms" : "Та салангид өрөөнүүдийг зогсоосон",
    "{actor} allowed guests" : "{actor} зочдыг зөвшөөрсөн",
    "You allowed guests" : "Та зочдыг зөвшөөрсөн",
    "An administrator allowed guests" : "Администратор зочдыг зөвшөөрсөн",
    "{actor} disallowed guests" : "{actor} зочдыг хориглосон",
    "You disallowed guests" : "Та зочдыг хориглосон",
    "An administrator disallowed guests" : "Администратор зочдыг хориглосон",
    "{actor} set a password" : "{actor} нууц үг тохируулсан",
    "You set a password" : "Та нууц үг тохируулсан",
    "An administrator set a password" : "Администратор нууц үг тохируулсан",
    "{actor} removed the password" : "{actor} нууц үгийг устгасан",
    "You removed the password" : "Та нууц үгийг устгасан",
    "An administrator removed the password" : "Администратор нууц үгийг устгасан",
    "{actor} added {user}" : "{actor} {user}-ыг нэмсэн",
    "You joined the conversation" : "Та яриад нэгдсэн",
    "{actor} joined the conversation" : "{actor} яриад нэгдсэн",
    "You added {user}" : "Та {user}-ыг нэмсэн",
    "{actor} added you" : "{actor} таныг нэмсэн",
    "An administrator added you" : "Администратор таныг нэмсэн",
    "An administrator added {user}" : "Администратор {user}-ыг нэмсэн",
    "You left the conversation" : "Та яриаг орхисон",
    "{actor} left the conversation" : "{actor} яриаг орхисон",
    "{actor} removed {user}" : "{actor} {user}-ыг хассан",
    "You removed {user}" : "Та {user}-ыг хассан",
    "{actor} removed you" : "{actor} таныг хассан",
    "An administrator removed you" : "Администратор таныг хассан",
    "An administrator removed {user}" : "Администратор {user}-ыг хассан",
    "{actor} invited {federated_user}" : "{actor} {federated_user}-ыг урисан",
    "You invited {federated_user}" : "Та {federated_user}-ыг урисан",
    "You accepted the invitation" : "Та урилгыг зөвшөөрсөн",
    "{actor} invited you" : "{actor} таныг урисан",
    "An administrator invited you" : "Администратор таныг урисан",
    "An administrator invited {federated_user}" : "Администратор {federated_user}-ыг урисан",
    "{federated_user} accepted the invitation" : "{federated_user} урилгыг зөвшөөрсөн",
    "{actor} removed {federated_user}" : "{actor} {federated_user}-ыг хассан",
    "You removed {federated_user}" : "Та {federated_user}-ыг хассан",
    "You declined the invitation" : "Та урилгаас татгалзсан",
    "An administrator removed {federated_user}" : "Администратор {federated_user}-ыг хассан",
    "{federated_user} declined the invitation" : "{federated_user} урилгаас татгалзсан",
    "{actor} added group {group}" : "{actor} {group} бүлгийг нэмсэн",
    "You added group {group}" : "Та {group} бүлгийг нэмсэн",
    "An administrator added group {group}" : "Администратор {group} бүлгийг нэмсэн",
    "{actor} removed group {group}" : "{actor} {group} бүлгийг хассан",
    "You removed group {group}" : "Та {group} бүлгийг хассан",
    "An administrator removed group {group}" : "Администратор {group} бүлгийг хассан",
    "{actor} added team {circle}" : "{actor} {circle} багийг нэмсэн",
    "You added team {circle}" : "Та {circle} багийг нэмсэн",
    "An administrator added team {circle}" : "Администратор {circle} багийг нэмсэн",
    "{actor} removed team {circle}" : "{actor} {circle} багийг хассан",
    "You removed team {circle}" : "Та {circle} багийг хассан",
    "An administrator removed team {circle}" : "Администратор {circle} багийг хассан",
    "{actor} added {phone}" : "{actor} {phone}-ыг нэмсэн",
    "You added {phone}" : "Та {phone}-ыг нэмсэн",
    "An administrator added {phone}" : "Администратор {phone}-ыг нэмсэн",
    "{actor} removed {phone}" : "{actor} {phone}-ыг хассан",
    "You removed {phone}" : "Та {phone}-ыг хассан",
    "An administrator removed {phone}" : "Администратор {phone}-ыг хассан",
    "{actor} promoted {user} to moderator" : "{actor} {user}-ыг модератор болгосон",
    "You promoted {user} to moderator" : "Та {user}-ыг модератор болгосон",
    "{actor} promoted you to moderator" : "{actor} таныг модератор болгосон",
    "An administrator promoted you to moderator" : "Администратор таныг модератор болгосон",
    "An administrator promoted {user} to moderator" : "Администратор {user}-ыг модератор болгосон",
    "{actor} demoted {user} from moderator" : "{actor} {user}-ыг модератор эрхээс хассан",
    "You demoted {user} from moderator" : "Та {user}-ыг модератор эрхээс хассан",
    "{actor} demoted you from moderator" : "{actor} таныг модератор эрхээс хассан",
    "An administrator demoted you from moderator" : "Администратор таныг модератор эрхээс хассан",
    "An administrator demoted {user} from moderator" : "Администратор {user}-ыг модератор эрхээс хассан",
    "{actor} shared a file which is no longer available" : "{actor} хүчингүй болсон файл хуваалцсан",
    "You shared a file which is no longer available" : "Та хүчингүй болсон файл хуваалцсан",
    "File shares are currently not supported in federated conversations" : "Файл хуваалцах нь федерац ярианд одоогоор дэмжигдэхгүй байна",
    "The shared location is malformed" : "Хуваалцсан байршил буруу форматтай байна",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} энэ яриаг бусад чатуудтай синхрончлохын тулд Matterbridge тохируулсан",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Та энэ яриаг бусад чатуудтай синхрончлохын тулд Matterbridge тохируулсан",
    "{actor} created thread {title}" : "{actor} {title} thread үүсгэсэн",
    "You created thread {title}" : "Та {title} thread үүсгэсэн",
    "{actor} renamed thread {title}" : "{actor} {title} thread-ийн нэрийг өөрчилсөн",
    "You renamed thread {title}" : "Та {title} thread-ийн нэрийг өөрчилсөн",
    "{actor} updated the Matterbridge configuration" : "{actor} Matterbridge тохиргоог шинэчилсэн",
    "You updated the Matterbridge configuration" : "Та Matterbridge тохиргоог шинэчилсэн",
    "{actor} removed the Matterbridge configuration" : "{actor} Matterbridge тохиргоог устгасан",
    "You removed the Matterbridge configuration" : "Та Matterbridge тохиргоог устгасан",
    "{actor} started Matterbridge" : "{actor} Matterbridge-г эхлүүлсэн",
    "You started Matterbridge" : "Та Matterbridge-г эхлүүлсэн",
    "{actor} stopped Matterbridge" : "{actor} Matterbridge-г зогсоосон",
    "You stopped Matterbridge" : "Та Matterbridge-г зогсоосон",
    "{actor} deleted a message" : "{actor} мессеж устгасан",
    "You deleted a message" : "Та мессеж устгасан",
    "{actor} edited a message" : "{actor} мессеж засварласан",
    "You edited a message" : "Та мессеж засварласан",
    "{actor} pinned a message" : "{actor} мессеж бэхэлсэн",
    "You pinned a message" : "Та мессеж бэхэлсэн",
    "{actor} unpinned a message" : "{actor} мессеж бэхлэлтийг тайлсан",
    "Message was automatically unpinned" : "Мессежийн бэхлэлт автоматаар тайлагдсан",
    "You unpinned a message" : "Та мессеж бэхлэлтийг тайлсан",
    "{actor} deleted a reaction" : "{actor} хариу үйлдлийг устгасан",
    "You deleted a reaction" : "Та хариу үйлдлийг устгасан",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Та зурвасын хугацааг %n долоо хоног болгож тохируулсан","Та зурвасын хугацааг %n долоо хоног болгож тохируулсан"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Та зурвасын хугацааг %n өдөр болгож тохируулсан","Та зурвасын хугацааг %n өдөр болгож тохируулсан"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Та зурвасын хугацааг %n цаг болгож тохируулсан","Та зурвасын хугацааг %n цаг болгож тохируулсан"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Та зурвасын хугацааг %n минут болгож тохируулсан","Та зурвасын хугацааг %n минут болгож тохируулсан"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} зурвасын хугацааг %n долоо хоног болгож тохируулсан","{actor} зурвасын хугацааг %n долоо хоног болгож тохируулсан"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} зурвасын хугацааг %n өдөр болгож тохируулсан","{actor} зурвасын хугацааг %n өдөр болгож тохируулсан"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} зурвасын хугацааг %n цаг болгож тохируулсан","{actor} зурвасын хугацааг %n цаг болгож тохируулсан"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} зурвасын хугацааг %n минут болгож тохируулсан","{actor} зурвасын хугацааг %n минут болгож тохируулсан"],
    "{actor} disabled message expiration" : "{actor} мессежийн дуусах хугацааг идэвхгүй болгосон",
    "You disabled message expiration" : "Та мессежийн дуусах хугацааг идэвхгүй болгосон",
    "{actor} cleared the history of the conversation" : "{actor} ярианы түүхийг цэвэрлэсэн",
    "You cleared the history of the conversation" : "Та ярианы түүхийг цэвэрлэсэн",
    "{actor} set the conversation picture" : "{actor} ярианы зургийг тохируулсан",
    "You set the conversation picture" : "Та ярианы зургийг тохируулсан",
    "{actor} removed the conversation picture" : "{actor} ярианы зургийг устгасан",
    "You removed the conversation picture" : "Та ярианы зургийг устгасан",
    "{actor} ended the poll {poll}" : "{actor} {poll} санал асуулгыг дуусгасан",
    "You ended the poll {poll}" : "Та {poll} санал асуулгыг дуусгасан",
    "{actor} started the video recording" : "{actor} видео бичлэгийг эхлүүлсэн",
    "You started the video recording" : "Та видео бичлэгийг эхлүүлсэн",
    "{actor} stopped the video recording" : "{actor} видео бичлэгийг зогсоосон",
    "You stopped the video recording" : "Та видео бичлэгийг зогсоосон",
    "{actor} started the audio recording" : "{actor} аудио бичлэгийг эхлүүлсэн",
    "You started the audio recording" : "Та аудио бичлэгийг эхлүүлсэн",
    "{actor} stopped the audio recording" : "{actor} аудио бичлэгийг зогсоосон",
    "You stopped the audio recording" : "Та аудио бичлэгийг зогсоосон",
    "The recording failed" : "Бичлэг амжилтгүй болсон",
    "Someone voted on the poll {poll}" : "Хэн нэгэн {poll} санал асуулгад санал өгсөн",
    "Message deleted by author" : "Мессеж зохиогчоор устгагдсан",
    "Message deleted by {actor}" : "Мессеж {actor}-аар устгагдсан",
    "Message deleted by you" : "Мессеж таны устгасан",
    "Deleted user" : "Устгагдсан хэрэглэгч",
    "Unknown number" : "Үл мэдэгдэх дугаар",
    "Administration" : "Удирдлага",
    "System" : "–°–∏—Å—Ç–µ–º",
    "%s (guest)" : "%s (зочин)",
    "Missed call" : "Алдагдсан дуудлага",
    "Unanswered call" : "Хариулаагүй дуудлага",
    "Call ended (Duration {duration})" : "Дуудлага дууссан (Үргэлжлэх хугацаа {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Дуудлага дууссан, учир нь хамгийн их дуудлагын хугацаанд хүрсэн (Үргэлжлэх хугацаа {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} дуудлагыг дуусгасан (Үргэлжлэх хугацаа {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["%n зочинтой дуудлага дээд хугацаанд хүрсэн тул дууссан (Үргэлжилсэн хугацаа {duration})","%n зочинтой дуудлага дээд хугацаанд хүрсэн тул дууссан (Үргэлжилсэн хугацаа {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["%n зочинтой дуудлага дууссан (Үргэлжилсэн хугацаа {duration})","%n зочинтой дуудлага дууссан (Үргэлжилсэн хугацаа {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} %n зочинтой дуудлагыг дуусгасан (Үргэлжилсэн хугацаа {duration})","{actor} %n зочинтой дуудлагыг дуусгасан (Үргэлжилсэн хугацаа {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1}-тай дуудлага дууссан, учир нь хамгийн их дуудлагын хугацаанд хүрсэн (Үргэлжлэх хугацаа {duration})",
    "Call with {user1} ended (Duration {duration})" : "{user1}-тай дуудлага дууссан (Үргэлжлэх хугацаа {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} {user1}-тай дуудлагыг дуусгасан (Үргэлжлэх хугацаа {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1} болон {user2}-тай дуудлага дууссан, учир нь хамгийн их дуудлагын хугацаанд хүрсэн (Үргэлжлэх хугацаа {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "{user1} болон {user2}-тай дуудлага дууссан (Үргэлжлэх хугацаа {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} {user1} болон {user2}-тай дуудлагыг дуусгасан (Үргэлжлэх хугацаа {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1}, {user2} болон {user3}-тай дуудлага дууссан, учир нь хамгийн их дуудлагын хугацаанд хүрсэн (Үргэлжлэх хугацаа {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "{user1}, {user2} болон {user3}-тай дуудлага дууссан (Үргэлжлэх хугацаа {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} {user1}, {user2} болон {user3}-тай дуудлагыг дуусгасан (Үргэлжлэх хугацаа {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1}, {user2}, {user3} болон {user4}-тай дуудлага дууссан, учир нь хамгийн их дуудлагын хугацаанд хүрсэн (Үргэлжлэх хугацаа {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "{user1}, {user2}, {user3} болон {user4}-тай дуудлага дууссан (Үргэлжлэх хугацаа {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} {user1}, {user2}, {user3} болон {user4}-тай дуудлагыг дуусгасан (Үргэлжлэх хугацаа {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1}, {user2}, {user3}, {user4} болон {user5}-тай дуудлага дууссан, учир нь хамгийн их дуудлагын хугацаанд хүрсэн (Үргэлжлэх хугацаа {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "{user1}, {user2}, {user3}, {user4} болон {user5}-тай дуудлага дууссан (Үргэлжлэх хугацаа {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} {user1}, {user2}, {user3}, {user4} болон {user5}-тай дуудлагыг дуусгасан (Үргэлжлэх хугацаа {duration})",
    "Message of {user} in {conversation}" : "{conversation} дахь {user}-ийн мессеж",
    "Message of {user}" : "{user}-ийн мессеж",
    "Message of a deleted user in {conversation}" : "{conversation} дахь устгагдсан хэрэглэгчийн мессеж",
    "Talk conversations" : "Talk яриа",
    "Talk to %s" : "%s-тай ярих",
    "An error occurred. Please contact your administrator." : "Алдаа гарлаа. Администратортайгаа холбогдоно уу.",
    "File not found" : "–§–∞–π–ª –æ–ª–¥—Å–æ–Ω–≥“Ø–π",
    "File is not shared, or shared but not with the user" : "Файл хуваалцаагүй эсвэл хуваалцсан боловч хэрэглэгчтэй биш",
    "No account available to delete." : "Устгах бүртгэл байхгүй.",
    "Poll" : "Санал асуулга",
    "Password needs to be set" : "Нууц үг тохируулах шаардлагатай",
    "Uploading the file failed" : "Файл байршуулах амжилтгүй болсон",
    "No image file provided" : "Зургийн файл өгөгдөөгүй",
    "File is too big" : "–§–∞–π–ª—ã–Ω —Ö—ç–º–∂—ç—ç —Ö—ç—Ç –∏—Ö –±–∞–π–Ω–∞",
    "Invalid file provided" : "–ë—É—Ä—É—É —Ñ–∞–π–ª –±–∞–π–Ω–∞",
    "Invalid image" : "–±—É—Ä—É—É –∑—É—Ä–∞–≥",
    "Unknown filetype" : "“Æ–ª –º—ç–¥—ç–≥–¥—ç—Ö —Ñ–∞–π–ª—ã–Ω —Ç”©—Ä”©–ª",
    "Talk mentions" : "Talk дурдалтууд",
    "More conversations" : "Бусад яриа",
    "Say hi to your friends and colleagues!" : "Найз нөхөд болон хамт олондоо мэндчил!",
    "No unread mentions" : "Уншаагүй дурдалт байхгүй",
    "Call in progress" : "Дуудлага явагдаж байна",
    "You were mentioned" : "Танийг дурдсан",
    "Write to conversation" : "Яриа руу бичих",
    "Writes event information into a conversation of your choice" : "Таны сонгосон яриа руу үйл явдлын мэдээлэл бичих",
    "Missing email field in header line" : "Толгой мөрөнд имэйл талбар дутуу",
    "Following lines are invalid: %s" : "Дараах мөрүүд буруу: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s таныг \"%2$s\" яриа руу урисан.",
    "You were invited to conversation \"%s\"." : "Та \"%s\" яриа руу урьсан.",
    "Conversation invitation" : "Ярианы урилга",
    "Scheduled time" : "Товлосон цаг",
    "Description" : "–¢–∞–π–ª–±–∞—Ä",
    "You can also dial-in via phone with the following details" : "Та мөн дараах мэдээллийг ашиглан утсаар залгаж болно",
    "Dial-in information" : "Залгах мэдээлэл",
    "Meeting ID" : "Уулзалтын ID",
    "Your PIN" : "Таны PIN",
    "Click the button below to join the lobby now." : "Хүлээлгийн танхимд нэгдэхийн тулд доорх товчийг дарна уу.",
    "Click the link below to join the lobby now." : "Хүлээлгийн танхимд нэгдэхийн тулд доорх холбоос дээр дарна уу.",
    "Join lobby for \"%s\"" : "\"%s\" хүлээлгийн танхимд нэгдэх",
    "Click the button below to join the conversation now." : "Яриад нэгдэхийн тулд доорх товчийг дарна уу.",
    "Click the link below to join the conversation now." : "Яриад нэгдэхийн тулд доорх холбоос дээр дарна уу.",
    "Join \"%s\"" : "\"%s\" нэгдэх",
    "Meeting" : "Уулзалт",
    "Password request: %s" : "Нууц үг хүсэлт: %s",
    "Private conversation" : "Хувийн яриа",
    "Deleted user (%s)" : "Устгагдсан хэрэглэгч (%s)",
    "Failed to upload call recording" : "Дуудлагын бичлэг байршуулах амжилтгүй болсон",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Бичлэгийн сервер {call} дуудлагын бичлэгийг байршуулж чадсангүй. Администрацитай холбогдоно уу.",
    "Share to chat" : "Чат руу хуваалцах",
    "Dismiss notification" : "Мэдэгдлийг хаах",
    "Call recording now available" : "Дуудлагын бичлэг одоо боломжтой",
    "The recording for the call in {call} was uploaded to {file}." : "{call} дахь дуудлагын бичлэг {file} руу байршуулагдсан.",
    "Transcript now available" : "Транскрипц одоо боломжтой",
    "The transcript for the call in {call} was uploaded to {file}." : "{call} дахь дуудлагын транскрипц {file} руу байршуулагдсан.",
    "Failed to transcript call recording" : "Дуудлагын бичлэгийг транскрипц хийх амжилтгүй болсон",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Сервер {call} дахь дуудлагын {file} бичлэгийг хуулбарлаж чадсангүй. Администрацитай холбогдоно уу.",
    "Call summary now available" : "Дуудлагын хураангуй одоо боломжтой",
    "The summary for the call in {call} was uploaded to {file}." : "{call} дахь дуудлагын хураангуй {file} руу байршуулагдсан.",
    "Failed to summarize call recording" : "Дуудлагын бичлэгийг хураангуйлах амжилтгүй болсон",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Сервер {call} дахь дуудлагын {file} бичлэгийг хураангуйлж чадсангүй. Администрацитай холбогдоно уу.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} таныг {remoteServer} дээрх {roomName} руу нэгдэхийг урисан",
    "Accept" : "–•“Ø–ª—ç—ç–Ω –∑”©–≤—à”©”©—Ä”©—Ö",
    "Decline" : "–ó”©–≤—à”©”©—Ä”©—Ö–≥“Ø–π",
    "{user1} invited you to a federated conversation" : "{user1} таныг федерац яриа руу урисан",
    "Someone reacted" : "Хэн нэгэн хариу үйлдэл үзүүлсэн",
    "New message" : "—à–∏–Ω—ç –∑—É—Ä–≤–∞—Å",
    "Reminder" : "Сануулга",
    "Someone mentioned you" : "Хэн нэгэн таныг дурдсан",
    "Notification" : "Мэдэгдэл",
    "Someone reacted in a private conversation" : "Хэн нэгэн хувийн яриад хариу үйлдэл үзүүлсэн",
    "You received a message in a private conversation" : "Та хувийн яриад мессеж хүлээн авлаа",
    "Reminder in a private conversation" : "Хувийн яриад сануулга",
    "Someone mentioned you in a private conversation" : "Хэн нэгэн таныг хувийн яриад дурдсан",
    "Notification in a private conversation" : "Хувийн яриад мэдэгдэл",
    "Reminder: You in {call}" : "Сануулга: Та {call}-д",
    "Reminder: {user} in {call}" : "Сануулга: {user} {call}-д",
    "Reminder: Deleted user in {call}" : "Сануулга: Устгагдсан хэрэглэгч {call}-д",
    "Reminder: {guest} (guest) in {call}" : "Сануулга: {guest} (зочин) {call}-д",
    "Reminder: Guest in {call}" : "Сануулга: Зочин {call}-д",
    "{user} reacted with {reaction}" : "{user} {reaction} хариу үйлдэл үзүүлсэн",
    "{user} reacted with {reaction} in {call}" : "{user} {call}-д {reaction} хариу үйлдэл үзүүлсэн",
    "Deleted user reacted with {reaction} in {call}" : "Устгагдсан хэрэглэгч {call}-д {reaction} хариу үйлдэл үзүүлсэн",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (зочин) {call}-д {reaction} хариу үйлдэл үзүүлсэн",
    "Guest reacted with {reaction} in {call}" : "Зочин {call}-д {reaction} хариу үйлдэл үзүүлсэн",
    "{user} in {call}" : "{user} {call}-д",
    "Deleted user in {call}" : "Устгагдсан хэрэглэгч {call}-д",
    "{guest} (guest) in {call}" : "{guest} (зочин) {call}-д",
    "Guest in {call}" : "Зочин {call}-д",
    "{user} sent you a private message" : "{user} танд хувийн мессеж илгээсэн",
    "{user} sent a message in conversation {call}" : "{user} {call} яриад мессеж илгээсэн",
    "A deleted user sent a message in conversation {call}" : "Устгагдсан хэрэглэгч {call} яриад мессеж илгээсэн",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (зочин) {call} яриад мессеж илгээсэн",
    "A guest sent a message in conversation {call}" : "Зочин {call} яриад мессеж илгээсэн",
    "{user} replied to your private message" : "{user} таны хувийн мессежид хариулсан",
    "{user} replied to your message in conversation {call}" : "{user} {call} яриад таны мессежид хариулсан",
    "A deleted user replied to your message in conversation {call}" : "Устгагдсан хэрэглэгч {call} яриад таны мессежид хариулсан",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (зочин) {call} яриад таны мессежид хариулсан",
    "A guest replied to your message in conversation {call}" : "Зочин {call} яриад таны мессежид хариулсан",
    "Reminder: You in private conversation {call}" : "Сануулга: Та {call} хувийн харилцан яриад",
    "Reminder: A deleted user in private conversation {call}" : "Сануулга: Устгагдсан хэрэглэгч {call} хувийн харилцан яриад",
    "Reminder: {user} in private conversation" : "Сануулга: {user} хувийн харилцан яриад",
    "Reminder: You in conversation {call}" : "Сануулга: Та {call} харилцан яриад",
    "Reminder: {user} in conversation {call}" : "Сануулга: {user} {call} харилцан яриад",
    "Reminder: A deleted user in conversation {call}" : "Сануулга: Устгагдсан хэрэглэгч {call} харилцан яриад",
    "Reminder: {guest} (guest) in conversation {call}" : "Сануулга: {guest} (зочин) {call} харилцан яриад",
    "Reminder: A guest in conversation {call}" : "Сануулга: Зочин {call} харилцан яриад",
    "{user} reacted with {reaction} to your private message" : "{user} таны хувийн мессежид {reaction} хариу үйлдэл үзүүлсэн",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} {call} харилцан ярианд таны мессежид {reaction} хариу үйлдэл үзүүлсэн",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Устгагдсан хэрэглэгч {call} яриан дахь таны мессежид {reaction} хариу үйлдэл үзүүлсэн",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (зочин) {call} яриан дахь таны мессежид {reaction} хариу үйлдэл үзүүлсэн",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Зочин {call} харилцан ярианд таны мессежид {reaction} хариу үйлдэл үзүүлсэн",
    "{user} mentioned you in a private conversation" : "{user} таныг хувийн харилцан ярианд дурдсан",
    "{user} mentioned group {group} in conversation {call}" : "{user} {call} харилцан ярианд {group} бүлгийг дурдсан",
    "{user} mentioned team {team} in conversation {call}" : "{user} {call} харилцан ярианд {team} багийг дурдсан",
    "{user} mentioned everyone in conversation {call}" : "{user} {call} харилцан ярианд бүгдийг дурдсан",
    "{user} mentioned you in conversation {call}" : "{user} {call} харилцан ярианд таныг дурдсан",
    "A deleted user mentioned group {group} in conversation {call}" : "Устгагдсан хэрэглэгч {call} харилцан ярианд {group} бүлгийг дурдсан",
    "A deleted user mentioned team {team} in conversation {call}" : "Устгагдсан хэрэглэгч {call} харилцан ярианд {team} багийг дурдсан",
    "A deleted user mentioned everyone in conversation {call}" : "Устгагдсан хэрэглэгч {call} харилцан ярианд бүгдийг дурдсан",
    "A deleted user mentioned you in conversation {call}" : "Устгагдсан хэрэглэгч {call} харилцан ярианд таныг дурдсан",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (зочин) {call} харилцан ярианд {group} бүлгийг дурдсан",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (зочин) {call} харилцан ярианд {team} багийг дурдсан",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (зочин) {call} харилцан ярианд бүгдийг дурдсан",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (зочин) {call} харилцан ярианд таныг дурдсан",
    "A guest mentioned group {group} in conversation {call}" : "Зочин {call} харилцан ярианд {group} бүлгийг дурдсан",
    "A guest mentioned team {team} in conversation {call}" : "Зочин {call} харилцан ярианд {team} багийг дурдсан",
    "A guest mentioned everyone in conversation {call}" : "Зочин {call} харилцан ярианд бүгдийг дурдсан",
    "A guest mentioned you in conversation {call}" : "Зочин {call} харилцан ярианд таныг дурдсан",
    "View message" : "Мессеж харах",
    "Dismiss reminder" : "Сануулгыг хаах",
    "View chat" : "Чат харах",
    "{user} invited you to a group conversation: {call}" : "{user} таныг бүлгийн яриа руу урисан: {call}",
    "Join call" : "Дуудлагад нэгдэх",
    "Answer call" : "Дуудлага хариулах",
    "{user} would like to talk with you" : "{user} тантай ярихыг хүсч байна",
    "Call back" : "Буцаж залгах",
    "You missed a call from {user}" : "Та {user}-ийн дуудлагыг алдсан",
    "Accept call" : "Дуудлага хүлээн авах",
    "Incoming phone call from {call}" : "{call}-аас ирж буй утасны дуудлага",
    "You missed a phone call from {call}" : "Та {call}-ийн утасны дуудлагыг алдсан",
    "A group call has started in {call}" : "{call}-д бүлгийн дуудлага эхэлсэн",
    "You missed a group call in {call}" : "Та {call}-д бүлгийн дуудлагыг алдсан",
    "{email} is requesting the password to access {file}" : "{email} {file} файлд хандах нууц үг хүсч байна",
    "{email} tried to request the password to access {file}" : "{email} {file} файлд хандах нууц үг хүсэхийг оролдсон",
    "Someone is requesting the password to access {file}" : "Хэн нэгэн {file} файлд хандах нууц үг хүсч байна",
    "Someone tried to request the password to access {file}" : "Хэн нэгэн {file} файлд хандах нууц үг хүсэхийг оролдсон",
    "Open settings" : "Тохиргоо нээх",
    "Hosted signaling server added" : "Байршуулсан signaling сервер нэмэгдсэн",
    "The hosted signaling server is now configured and will be used." : "Байршуулсан signaling сервер тохируулагдсан ба ашиглагдах болно.",
    "Hosted signaling server removed" : "Байршуулсан signaling сервер устгагдсан",
    "The hosted signaling server was removed and will not be used anymore." : "Байршуулсан signaling сервер устгагдсан ба цаашид ашиглагдахгүй.",
    "Hosted signaling server changed" : "Байршуулсан signaling сервер өөрчлөгдсөн",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Байршуулсан дохионы серверийн бүртгэлийн төлөв \"{oldstatus}\"-аас \"{newstatus}\" болж өөрчлөгдсөн.",
    "pending" : "хүлээгдэж байна",
    "active" : "идэвхтэй",
    "expired" : "дууссан",
    "blocked" : "хаагдсан",
    "error" : "алдаа",
    "The certificate of {host} expires in {days} days" : "{host}-ийн сертификат {days} хоногийн дараа дуусна",
    "The certificate of {host} expired" : "{host}-ийн сертификат дууссан",
    "Contact via Talk" : "Talk-аар холбогдох",
    "Open Talk" : "Talk нээх",
    "Default" : "Өгөгдмөл",
    "Presentation" : "Танилцуулга",
    "Webinar" : "Вебинар",
    "Conversations" : "Яриа",
    "Messages in current conversation" : "Одоогийн ярианы мессежүүд",
    "{user}" : "{user}",
    "Messages" : "Мессежүүд",
    "{user} in {conversation}" : "{user} {conversation}-д",
    "Messages in other conversations" : "Бусад ярианы мессежүүд",
    "One-to-one rooms always need to show the other users avatar" : "Нэг нэгтэйгээ өрөөнүүд үргэлж нөгөө хэрэглэгчийн аватарыг харуулах шаардлагатай",
    "Invalid emoji character" : "Буруу эможи тэмдэгт",
    "Invalid background color" : "Буруу дэвсгэр өнгө",
    "Avatar image is not square" : "–•”©—Ä”©–≥ –∑—É—Ä–∞–≥ –¥”©—Ä–≤”©–ª–∂–∏–Ω –±–∏—à",
    "Room {number}" : "Өрөө {number}",
    "Other" : "–ë—É—Å–∞–¥",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Туршилтын сервер холбогдох боломжгүй тул туршилт хүсэж чадсангүй. Дараа дахин оролдоно уу.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Энэ серверийн нэвтрэлт танилтад асуудал байна. Магадгүй URL-ыг баталгаажуулахын тулд гаднаас хандах боломжгүй байж болно.",
    "Something unexpected happened." : "Гэнэтийн зүйл тохиолдлоо.",
    "The URL is invalid." : "URL буруу байна.",
    "An HTTPS URL is required." : "HTTPS URL шаардлагатай.",
    "The email address is invalid." : "Имэйл хаяг буруу байна.",
    "The language is invalid." : "Хэл буруу байна.",
    "The country is invalid." : "Улс буруу байна.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Туршилтын хүсэлтэд асуудал гарлаа. Дэлгэрэнгүй мэдээллийг логоос шалгана уу.",
    "Too many requests are send from your servers address. Please try again later." : "Таны серверийн хаягаас хэт олон хүсэлт илгээгдсэн. Дараа дахин оролдоно уу.",
    "There is already a trial registered for this Nextcloud instance." : "Энэ Nextcloud instance-д туршилт аль хэдийн бүртгэгдсэн байна.",
    "Something unexpected happened. Please try again later." : "Гэнэтийн зүйл тохиолдлоо. Дараа дахин оролдоно уу.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Туршилтын сервер буруу ажилласан тул туршилт хүсэж чадсангүй. Дараа дахин оролдоно уу.",
    "Trial requested but failed to get account information. Please check back later." : "Туршилт хүсэгдсэн боловч бүртгэлийн мэдээллийг авч чадсангүй. Дараа дахин шалгана уу.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Энэ хүсэлтийн нэвтрэлт танилтад асуудал байна. Магадгүй URL-ыг баталгаажуулахын тулд гаднаас хандах боломжгүй байж болно.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Туршилтын сервер буруу ажилласан тул бүртгэлийн мэдээллийг авч чадсангүй. Дараа дахин шалгана уу.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Бүртгэлийн мэдээллийг авахад асуудал гарлаа. Дэлгэрэнгүй мэдээллийг логоос шалгана уу.",
    "There is no such account registered." : "Ийм бүртгэл бүртгэгдээгүй байна.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Туршилтын сервер холбогдох боломжгүй тул бүртгэлийн мэдээллийг авч чадсангүй. Дараа дахин шалгана уу.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Байршуулсан дохионы серверийн бүртгэлийг устгаж чадсангүй. Дараа дахин шалгана уу.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Туршилтын сервер буруу ажилласан тул бүртгэлийг устгаж чадсангүй. Дараа дахин шалгана уу.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Бүртгэлийг устгахад асуудал гарлаа. Дэлгэрэнгүй мэдээллийг логоос шалгана уу.",
    "Too many requests are sent from your servers address. Please try again later." : "Таны серверийн хаягаас хэт олон хүсэлт илгээгдсэн. Дараа дахин оролдоно уу.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Туршилтын сервер холбогдох боломжгүй тул бүртгэлийг устгаж чадсангүй. Дараа дахин шалгана уу.",
    "Note to self" : "Өөртөө тэмдэглэл",
    "A place for your private notes, thoughts and ideas" : "Таны хувийн тэмдэглэл, бодол санаа бичих газар",
    "Transcript is AI generated and may contain mistakes" : "Транскрипц нь AI-аар үүсгэгдсэн бөгөөд алдаа агуулж болно",
    "Summary is AI generated and may contain mistakes" : "Хураангуй нь AI-аар үүсгэгдсэн бөгөөд алдаа агуулж болно",
    "Let's get started!" : "Эхэлцгээе!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** нь Nextcloud экосистемтэй нягт уялдсан, аюулгүй, өөрийн серверт байршуулдаг харилцааны платформ юм.\n\n#### Nextcloud Talk-ийн гол боломжууд:\n\n* Хувийн болон бүлгийн чатад мессеж бичих\n* Дуу болон видео дуудлага\n* Файл хуваалцах ба бусад Nextcloud аппуудтай нэгтгэх\n* Ярианы тохиргоо, модераци болон нууцлалын удирдлага\n* Вэб, ширээний компьютер болон гар утас (iOS ба Android)\n* Хувийн ба аюулгүй харилцаа\n\n Дэлгэрэнгүйг [хэрэглэгчийн баримт бичиг](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)-ээс үзнэ үү.",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Nextcloud Talk-д тавтай морил\n\nNextcloud Talk нь Nextcloud-тай нэгтгэгдсэн хувийн бөгөөд хүчирхэг мессежийн апп юм. Хувийн эсвэл бүлгийн яриагаар чатлах, дуу болон видео дуудлагаар хамтран ажиллах, вебинар болон арга хэмжээ зохион байгуулах, яриагаа тохируулах болон бусад олон боломжтой.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Та мессежид хариулах, бусад чат болон хүмүүст дамжуулах, эсвэл мессежийн агуулгыг хуулах боломжтой.",
    "Andorra" : "Андорра",
    "United Arab Emirates" : "Арабын Нэгдсэн Эмират",
    "Afghanistan" : "Афганистан",
    "Antigua and Barbuda" : "Антигуа ба Барбуда",
    "Anguilla" : "Ангилья",
    "Albania" : "Албани",
    "Armenia" : "Армени",
    "Angola" : "Ангол",
    "Antarctica" : "Антарктид",
    "Argentina" : "Аргентин",
    "American Samoa" : "Америкийн Самоа",
    "Austria" : "Австри",
    "Australia" : "Австрали",
    "Aruba" : "Аруба",
    "Åland Islands" : "Аланд арлууд",
    "Azerbaijan" : "Азербайжан",
    "Bosnia and Herzegovina" : "Босни Герцеговин",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Бельги",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "Болгар",
    "Bahrain" : "Бахрейн",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Сент-Бартелеми",
    "Bermuda" : "Бермуда",
    "Brunei Darussalam" : "Бруней",
    "Bolivia, Plurinational State of" : "Боливи",
    "Bonaire, Sint Eustatius and Saba" : "Бонэйр, Синт-Эстатиус ба Саба",
    "Brazil" : "Бразил",
    "Bahamas" : "Багамын арлууд",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "Бувэ арал",
    "Botswana" : "Ботсвана",
    "Belarus" : "Беларусь",
    "Belize" : "Белиз",
    "Canada" : "Канад",
    "Cocos (Keeling) Islands" : "Кокос (Кийлинг) арлууд",
    "Congo, the Democratic Republic of the" : "Бүгд Найрамдах Ардчилсан Конго",
    "Central African Republic" : "Төв Африкийн Бүгд Найрамдах Улс",
    "Congo" : "Конго",
    "Switzerland" : "Швейцарь",
    "Côte d'Ivoire" : "Кот-д'Ивуар",
    "Cook Islands" : "Күүкийн арлууд",
    "Chile" : "Чили",
    "Cameroon" : "Камерун",
    "China" : "Хятад",
    "Colombia" : "Колумб",
    "Costa Rica" : "Коста Рика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Кабо-Верде",
    "Curaçao" : "Кюрасао",
    "Christmas Island" : "Зул сарын арал",
    "Cyprus" : "Кипр",
    "Czechia" : "Чех",
    "Germany" : "Герман",
    "Djibouti" : "Джибути",
    "Denmark" : "Дани",
    "Dominica" : "Доминика",
    "Dominican Republic" : "Доминиканы Бүгд Найрамдах Улс",
    "Algeria" : "Алжир",
    "Ecuador" : "Эквадор",
    "Estonia" : "Эстони",
    "Egypt" : "Египет",
    "Western Sahara" : "Баруун Сахар",
    "Eritrea" : "Эритрей",
    "Spain" : "Испани",
    "Ethiopia" : "Этиоп",
    "Finland" : "Финланд",
    "Fiji" : "Фижи",
    "Falkland Islands (Malvinas)" : "Фолкландын арлууд",
    "Micronesia, Federated States of" : "Микронезийн Холбооны Улс",
    "Faroe Islands" : "Фарерын арлууд",
    "France" : "Франц",
    "Gabon" : "Габон",
    "United Kingdom of Great Britain and Northern Ireland" : "Их Британи ба Хойд Ирландын Нэгдсэн Хаант Улс",
    "Grenada" : "Гренада",
    "Georgia" : "Гүрж",
    "French Guiana" : "Францын Гвиана",
    "Guernsey" : "Гернси",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренланд",
    "Gambia" : "Гамби",
    "Guinea" : "Гвиней",
    "Guadeloupe" : "Гваделуп",
    "Equatorial Guinea" : "Экваторын Гвиней",
    "Greece" : "Грек",
    "South Georgia and the South Sandwich Islands" : "Өмнөд Жоржиа ба Өмнөд Сэндвичийн арлууд",
    "Guatemala" : "Гватемал",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвиней-Бисау",
    "Guyana" : "Гайана",
    "Hong Kong" : "Хонг Конг",
    "Heard Island and McDonald Islands" : "Херд арал ба Макдональд арлууд",
    "Honduras" : "Гондурас",
    "Croatia" : "Хорват",
    "Haiti" : "Гаити",
    "Hungary" : "Унгар",
    "Indonesia" : "Индонез",
    "Ireland" : "Ирланд",
    "Israel" : "Израиль",
    "Isle of Man" : "Мэн арал",
    "India" : "Энэтхэг",
    "British Indian Ocean Territory" : "Британийн Энэтхэгийн далайн нутаг дэвсгэр",
    "Iraq" : "Ирак",
    "Iran, Islamic Republic of" : "Иран",
    "Iceland" : "Исланд",
    "Italy" : "Итали",
    "Jersey" : "Жерси",
    "Jamaica" : "Ямайка",
    "Jordan" : "Иордан",
    "Japan" : "Япон",
    "Kenya" : "Кени",
    "Kyrgyzstan" : "Киргиз",
    "Cambodia" : "Камбож",
    "Kiribati" : "Кирибати",
    "Comoros" : "Коморын арлууд",
    "Saint Kitts and Nevis" : "Сент-Киттс ба Невис",
    "Korea, Democratic People's Republic of" : "Хойд Солонгос",
    "Korea, Republic of" : "Өмнөд Солонгос",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Кайманы арлууд",
    "Kazakhstan" : "Казахстан",
    "Lao People's Democratic Republic" : "Лаос",
    "Lebanon" : "Ливан",
    "Saint Lucia" : "Сент-Люсиа",
    "Liechtenstein" : "Лихтенштейн",
    "Sri Lanka" : "Шри-Ланка",
    "Liberia" : "Либери",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латви",
    "Libya" : "Ливи",
    "Morocco" : "Марокко",
    "Monaco" : "Монако",
    "Moldova, Republic of" : "Молдав",
    "Montenegro" : "Монтенегро",
    "Saint Martin (French part)" : "Сент-Мартин (Францын хэсэг)",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршаллын арлууд",
    "North Macedonia" : "Хойд Македони",
    "Mali" : "Мали",
    "Myanmar" : "Мьянмар",
    "Mongolia" : "Монгол",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Хойд Марианы арлууд",
    "Martinique" : "Мартиник",
    "Mauritania" : "Мавритан",
    "Montserrat" : "Монтсеррат",
    "Malta" : "Мальта",
    "Mauritius" : "Маврикий",
    "Maldives" : "Мальдив",
    "Malawi" : "Малави",
    "Mexico" : "Мексик",
    "Malaysia" : "Малайз",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намиби",
    "New Caledonia" : "Шинэ Каледони",
    "Niger" : "Нигер",
    "Norfolk Island" : "Норфолк арал",
    "Nigeria" : "Нигери",
    "Nicaragua" : "Никарагуа",
    "Netherlands" : "Нидерланд",
    "Norway" : "Норвеги",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ниуэ",
    "New Zealand" : "Шинэ Зеланд",
    "Oman" : "Оман",
    "Panama" : "Панам",
    "Peru" : "Перу",
    "French Polynesia" : "Францын Полинез",
    "Papua New Guinea" : "Папуа Шинэ Гвиней",
    "Philippines" : "Филиппин",
    "Pakistan" : "Пакистан",
    "Poland" : "Польш",
    "Saint Pierre and Miquelon" : "Сент-Пьер ба Микелон",
    "Pitcairn" : "Питкэрн",
    "Puerto Rico" : "Пуэрто-Рико",
    "Palestine, State of" : "Палестин",
    "Portugal" : "Португал",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Реюнион",
    "Romania" : "Румын",
    "Serbia" : "Серби",
    "Russian Federation" : "Орос",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудын Араб",
    "Solomon Islands" : "Соломоны арлууд",
    "Seychelles" : "Сейшелийн арлууд",
    "Sudan" : "Судан",
    "Sweden" : "Швед",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Сент-Хелена, Асенсион ба Тристан-да-Кунья",
    "Slovenia" : "Словени",
    "Svalbard and Jan Mayen" : "Свалбард ба Ян Майен",
    "Slovakia" : "Словак",
    "Sierra Leone" : "Сьерра-Леоне",
    "San Marino" : "Сан-Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомали",
    "Suriname" : "Суринам",
    "South Sudan" : "Өмнөд Судан",
    "Sao Tome and Principe" : "Сан-Томе ба Принсипи",
    "El Salvador" : "Эль Сальвадор",
    "Sint Maarten (Dutch part)" : "Синт-Мартен (Голландын хэсэг)",
    "Syrian Arab Republic" : "Сири",
    "Eswatini" : "Эсватини",
    "Turks and Caicos Islands" : "Тёркс ба Кайкос арлууд",
    "Chad" : "Чад",
    "French Southern Territories" : "Францын өмнөд нутаг дэвсгэр",
    "Togo" : "Того",
    "Thailand" : "Тайланд",
    "Tajikistan" : "Тажикстан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Зүүн Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Тонга",
    "Turkey" : "Турк",
    "Trinidad and Tobago" : "Тринидад ба Тобаго",
    "Tuvalu" : "Тувалу",
    "Taiwan, Province of China" : "Тайвань",
    "Tanzania, United Republic of" : "Танзани",
    "Ukraine" : "Украин",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "АНУ-ын бага алслагдсан арлууд",
    "United States of America" : "Америкийн Нэгдсэн Улс",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Ватикан",
    "Saint Vincent and the Grenadines" : "Сент-Винсент ба Гренадин",
    "Venezuela, Bolivarian Republic of" : "Венесуэл",
    "Virgin Islands, British" : "Британийн Виржиний арлууд",
    "Virgin Islands, U.S." : "АНУ-ын Виржиний арлууд",
    "Viet Nam" : "Вьетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уоллис ба Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Йемен",
    "Mayotte" : "Майотта",
    "South Africa" : "Өмнөд Африк",
    "Zambia" : "Замби",
    "Zimbabwe" : "Зимбабве",
    "Background blur" : "Дэвсгэр бүдгэрүүлэлт",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "WASM ачааллын дэмжлэгийг шалгаж чадсангүй. Вэб сервер `.wasm` файлуудыг үйлчилж байгаа эсэхийг гараар шалгана уу.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Таны вэб сервер `.wasm` файлуудыг зөв дамжуулахаар тохируулагдаагүй байна. Энэ нь ихэвчлэн Nginx тохиргооны асуудал юм. Арын дэвсгэрийн бүдэгрүүлэлтийн хувьд `.wasm` файлуудыг мөн дамжуулахаар тохируулах шаардлагатай. Nginx тохиргоогоо бидний баримт бичиг дэх зөвлөмж болгосон тохиргоотой харьцуулна уу.",
    "Talk configuration values" : "Talk тохиргооны утгууд",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Дуудлагын хугацааг албадах нь зөвхөн системийн cron-оор дэмжигддэг. Системийн cron-ыг идэвхжүүлэх эсвэл `max_call_duration` тохиргоог устгана уу.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Бага `max_call_duration` утгуудыг (одоо %d гэж тохируулагдсан) техникийн хязгаарлалтаас шалтгаалан хэрэгжүүлэх боломжгүй. Арын ажил зөвхөн 5 минут тутамд ажилладаг тул өөрийн эрсдэлээр ашиглана уу.",
    "Federation" : "—Ö–æ–ª–±–æ–æ",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Talk Federation идэвхжүүлсэн үед \"memcache.locking\" тохируулахыг зөвлөж байна.",
    "High-performance backend" : "Өндөр гүйцэтгэлтэй backend",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Өндөр гүйцэтгэлтэй backend тохируулагдаагүй - Nextcloud Talk-ыг Өндөр гүйцэтгэлтэй backend-гүйгээр ажиллуулах нь зөвхөн маш жижиг дуудлагуудад (хамгийн ихдээ 2-3 оролцогч) тохирно. Олон оролцогчтой дуудлагууд жигд ажиллахын тулд Өндөр гүйцэтгэлтэй backend тохируулна уу.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Өндөр гүйцэтгэлтэй backend-ийн \"conversation_cluster\" горимыг ажиллуулах нь хуучирсан бөгөөд дараагийн хувилбарт дэмжигдэхгүй болно. Өндөр гүйцэтгэлтэй backend одоо жинхэнэ кластерлалтыг дэмждэг бөгөөд үүнийг оронд нь ашиглах хэрэгтэй.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Олон Өндөр гүйцэтгэлтэй backend тодорхойлох нь хуучирсан бөгөөд дараагийн хувилбарт дэмжигдэхгүй болно. Үүний оронд кластерлагдсан дохионы серверүүдтэй хамт ачаалал тэнцвэржүүлэгч тохируулж, Talk тохиргоонд тохируулах хэрэгтэй.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "%1$s алгоритмд ашиглагдаж буй хадгалсан нийтийн түлхүүр хадгалсан хувийн түлхүүртэй таарахгүй байна. Асуудлыг засахын тулд %2$s ажиллуулна уу.",
    "High-performance backend not configured correctly. Run %s for details." : "Өндөр гүйцэтгэлтэй backend зөв тохируулагдаагүй. Дэлгэрэнгүй мэдээлэл авахын тулд %s-г ажиллуулна уу.",
    "High-performance backend not configured correctly" : "Өндөр гүйцэтгэлтэй backend зөв тохируулагдаагүй",
    "Error: Cannot connect to server" : "Алдаа: Серверт холбогдох боломжгүй",
    "Error: Server did not respond with proper JSON" : "Алдаа: Сервер зөв JSON-оор хариулсангүй",
    "Error: Certificate expired" : "Алдаа: Сертификат дууссан",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Алдаа: Nextcloud сервер болон Өндөр гүйцэтгэлтэй backend серверийн системийн цаг синхрончлогдоогүй байна. Хоёр серверийг цагийн серверт холбох эсвэл цагийг гараар синхрончилно уу.",
    "Could not get version" : "Хувилбарыг авч чадсангүй",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Алдаа: Ажиллаж буй хувилбар: {version}; Talk-ийн энэ хувилбартай нийцтэй болгохын тулд серверийг шинэчлэх шаардлагатай",
    "Error: Server responded with: {error}" : "Алдаа: Сервер хариулсан: {error}",
    "Error: Unknown error occurred" : "Алдаа: Үл мэдэгдэх алдаа гарлаа",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Анхааруулга: Ажиллаж буй хувилбар: {version}; Сервер Talk-ийн энэ хувилбарын бүх боломжуудыг дэмждэггүй, дутуу боломжууд: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Nextcloud Talk-ыг Өндөр гүйцэтгэлтэй backend-тэй ажиллуулахад санах ойн кэш тохируулахыг зөвлөж байна.",
    "Client Push" : "Клиент Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Client Push суулгагдсан, энэ нь Talk мэдэгдлүүдийн цаг тухайд нь ирэх байдлыг сайжруулна.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} суулгаагүй байна. Энэ нь Talk мэдэгдлүүдийг хоцроох магадлалтай.",
    "Recording backend" : "Бичлэгийн backend",
    "Using the recording backend requires a High-performance backend." : "Бичлэгийн backend ашиглахад Өндөр гүйцэтгэлтэй backend шаардлагатай.",
    "No recording backend configured" : "Бичлэгийн backend тохируулагдаагүй",
    "SIP configuration" : "SIP тохиргоо",
    "Using the SIP functionality requires a High-performance backend." : "SIP функционал ашиглахад Өндөр гүйцэтгэлтэй backend шаардлагатай.",
    "No SIP backend configured" : "SIP backend тохируулагдаагүй",
    "Invalid date, date format must be YYYY-MM-DD" : "Огноо буруу, огнооны формат YYYY-MM-DD байх ёстой",
    "Conversation not found" : "Яриа олдсонгүй",
    "Path is already shared with this conversation" : "Зам аль хэдийн энэ яриатай хуваалцагдсан байна",
    "Chat, video & audio-conferencing using WebRTC" : "WebRTC ашиглан чат, видео болон аудио хурал",
    "Leave call" : "Дуудлагаас гарах",
    "Navigating away from the page will leave the call in {conversation}" : "Хуудаснаас гарах нь {conversation} дуудлагаас гарна",
    "Stay in call" : "Дуудлагад үлдэх",
    "Error occurred when getting the conversation information" : "Ярианы мэдээлэл авахад алдаа гарлаа",
    "Discuss this file" : "Энэ файлыг хэлэлцэх",
    "Share this file with others to discuss it" : "Энэ файлыг бусадтай хуваалцаж хэлэлцэх",
    "Share this file" : "Энэ файлыг хуваалцах",
    "Join conversation" : "Яриад нэгдэх",
    "This conversation is password-protected." : "Энэ яриа нууц үгээр хамгаалагдсан.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Таны IP хаягаас олон удаагийн буруу нууц үг оруулах оролдлого илэрсэн. Тиймээс таны дараагийн оролдлогыг 30 секунд хүртэл хязгаарлав.",
    "The password is wrong. Try again." : "Нууц үг буруу байна. Дахин оролдоно уу.",
    "Password" : "–ù—É—É—Ü “Ø–≥",
    "Submit" : "–º—ç–¥—ç–≥–¥—ç—Ö",
    "Error requesting the password." : "Нууц үг хүсэхэд алдаа гарлаа.",
    "Request password" : "Нууц үг хүсэх",
    "This conversation has ended" : "Энэ яриа дууссан",
    "Error occurred when joining the conversation" : "Яриад нэгдэхэд алдаа гарлаа",
    "Close Talk sidebar" : "Talk хажуугийн мөрийг хаах",
    "Open Talk sidebar" : "Talk хажуугийн мөрийг нээх",
    "Everyone" : "–ë“Ø—Ö —Ö—ç—Ä—ç–≥–ª—ç–≥—á–∏–¥",
    "Users and moderators" : "Хэрэглэгчид болон модераторууд",
    "Moderators only" : "Зөвхөн модераторууд",
    "Disable calls" : "Дуудлагыг идэвхгүй болгох",
    "Save changes" : "”®”©—Ä—á–ª”©–ª—Ç–∏–π–≥ —Ö–∞–¥–≥–∞–ª–∞—Ö",
    "Saving …" : "Хадгалж байна …",
    "Saved!" : "–•–∞–¥–≥–∞–ª–∞–≥–¥–ª–∞–∞!",
    "Limit to groups" : "Бүлгүүдэд хязгаарлах",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Дор хаяж нэг бүлэг сонгогдсон үед зөвхөн жагсаасан бүлгүүдийн хүмүүс яриануудад оролцох боломжтой.",
    "Guests can still join public conversations." : "Зочид нийтийн яриануудад нэгдэх боломжтой хэвээр.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Talk ашиглах боломжгүй болсон хэрэглэгчид өмнөх яриануудад оролцогчоор жагсаасан хэвээр байх ба тэдний чат мессежүүд мөн хадгалагдана.",
    "Limit using Talk" : "Talk ашиглахыг хязгаарлах",
    "Limit creating a public and group conversation" : "Нийтийн болон бүлгийн яриа үүсгэхийг хязгаарлах",
    "Limit creating conversations" : "Яриа үүсгэхийг хязгаарлах",
    "Limit starting a call" : "Дуудлага эхлүүлэхийг хязгаарлах",
    "Limit starting calls" : "Дуудлага эхлүүлэхийг хязгаарлах",
    "When a call has started, everyone with access to the conversation can join the call." : "Дуудлага эхэлсэн үед яриад хандах эрхтэй бүх хүн дуудлагад нэгдэх боломжтой.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Дараах ботууд энэ серверт суулгагдсан. Баримт бичгээс {linkstart1}өөрийн бот хэрхэн бүтээх{linkend} эсвэл серверт идэвхжүүлэх {linkstart2}ботуудын жагсаалт{linkend}-ыг олж болно.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Энэ серверт ямар ч бот суулгагдаагүй байна. Баримт бичгээс {linkstart1}өөрийн бот хэрхэн бүтээх{linkend} эсвэл серверт идэвхжүүлэх {linkstart2}ботуудын жагсаалт{linkend}-ыг олж болно.",
    "Description is not provided" : "Тодорхойлолт өгөгдөөгүй",
    "Locked for moderators" : "Модераторуудад түгжигдсэн",
    "Enabled" : "–ò–¥—ç–≤—Ö–∏–∂“Ø“Ø–ª—ç—Ö",
    "Disabled" : "–∏–¥—ç–≤—Ö–∏–≥“Ø–π",
    "Bots settings" : "Ботуудын тохиргоо",
    "State" : "Төлөв",
    "Name" : "–ù—ç—Ä",
    "Last error" : "Сүүлийн алдаа",
    "Total errors count" : "Нийт алдааны тоо",
    "Find more bots" : "Илүү олон бот олох",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Итгэмжлэгдсэн серверүүдийг {linkstart}Хуваалцах тохиргооны хуудас{linkend}-аас тохируулж болно.",
    "Beta" : "Бета",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Холбогдсон чатууд болон дуудлагууд аль хэдийн ажиллаж байна. Хавсралт зохицуулалт ирээдүйн хувилбарт нэмэгдэнэ.",
    "Enable Federation in Talk app" : "Talk апп-д Федерацийг идэвхжүүлэх",
    "Permissions" : "Зөвшөөрлүүд",
    "Allow users to be invited to federated conversations" : "Хэрэглэгчдийг федерацийн яриануудад урих боломжийг зөвшөөрөх",
    "Allow users to invite federated users into conversation" : "Хэрэглэгчдэд федерацийн хэрэглэгчдийг яриад урих боломжийг зөвшөөрөх",
    "Only allow to federate with trusted servers" : "Зөвхөн итгэмжит серверүүдтэй федерац хийхийг зөвшөөрөх",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Дор хаяж нэг бүлэг сонгогдсон үед зөвхөн жагсаасан бүлгүүдийн хүмүүс холбогдсон хэрэглэгчдийг яриануудад урих боломжтой.",
    "Groups allowed to invite federated users" : "Федерацийн хэрэглэгчдийг урих эрхтэй бүлгүүд",
    "All messages" : "Бүх мессеж",
    "@-mentions only" : "Зөвхөн @-дурдалт",
    "Off" : "Унтраах",
    "General settings" : "Ерөнхий тохиргоо",
    "Default notification settings" : "Өгөгдмөл мэдэгдлийн тохиргоо",
    "Default group notification" : "Өгөгдмөл бүлгийн мэдэгдэл",
    "Default group notification for new groups" : "Шинэ бүлгүүдэд зориулсан өгөгдмөл бүлгийн мэдэгдэл",
    "Integration into other apps" : "Бусад апп-уудад нэгтгэл",
    "Allow conversations on files" : "Файлууд дээр яриа зөвшөөрөх",
    "Allow conversations on public shares for files" : "Файлуудын нийтийн хуваалцалт дээр яриа зөвшөөрөх",
    "End-to-end encrypted calls" : "Төгсгөлөөс төгсгөл хүртэл шифрлэгдсэн дуудлагууд",
    "Enable encryption" : "Шифрлэлтийг идэвхжүүлэх",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "SIP гүүртэй тохируулсан төгсгөлөөс төгсгөл хүртэл шифрлэгдсэн дуудлагууд нь Өндөр гүйцэтгэлтэй backend болон SIP гүүрийн шинэ хувилбар шаарддаг.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Гар утасны клиентүүд одоогоор төгсгөлөөс төгсгөл хүртэл шифрлэгдсэн дуудлагыг дэмждэггүй.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Дээрх товчийг дарснаар маягтын мэдээллийг Struktur AG-ийн серверүүд рүү илгээнэ. Нэмэлт мэдээллийг {linkstart}spreed.eu{linkend}-аас олж болно.",
    "Pending" : "–•“Ø–ª—ç—ç–≥–¥—ç–∂ –±–∞–π–≥–∞–∞",
    "Error" : "–ê–ª–¥–∞–∞",
    "Blocked" : "–•–∞–∞–≥–¥—Å–∞–Ω",
    "Active" : "Идэвхтэй",
    "Expired" : "Дууссан",
    "Never" : "—Ö—ç–∑—ç—ç—á",
    "The trial could not be requested. Please try again later." : "Туршилтыг хүсэх боломжгүй байна. Дараа дахин оролдоно уу.",
    "The account could not be deleted. Please try again later." : "Бүртгэлийг устгах боломжгүй байна. Дараа дахин оролдоно уу.",
    "Hosted High-performance backend" : "Хостлогдсон Өндөр гүйцэтгэлтэй backend",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Бидний хамтрагч Struktur AG нь байршуулсан дохионы сервер хүсэх үйлчилгээ үзүүлдэг. Үүний тулд доорх маягтыг бөглөхөд л хангалттай бөгөөд таны Nextcloud хүсэлт илгээх болно. Сервер тохируулагдсаны дараа нэвтрэх мэдээлэл автоматаар бөглөгдөнө. Энэ нь одоо байгаа дохионы серверийн тохиргоог дарж бичнэ.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Хэрэв таны Өндөр гүйцэтгэлтэй backend бүртгэлд STUN ба/эсвэл TURN функц багтсан бол тохиргоо зохих ёсоор шинэчлэгдэнэ.",
    "URL of this Nextcloud instance" : "Энэ Nextcloud instance-ийн URL",
    "Full name of the user requesting the trial" : "Туршилт хүсэж буй хэрэглэгчийн бүтэн нэр",
    "Email of the user" : "Хэрэглэгчийн имэйл",
    "Language" : "–•—ç–ª",
    "Country" : "–£–ª—Å",
    "Request signaling server trial" : "Сигнал серверийн туршилт хүсэх",
    "You can see the current status of your hosted signaling server in the following table." : "Байршуулсан дохионы серверийнхээ одоогийн төлөвийг дараах хүснэгтээс харж болно.",
    "Status" : "—Ç”©–ª”©–≤",
    "Created at" : "“Ø“Ø—Å–≥—ç–≥–¥—Å—ç–Ω",
    "Expires at" : "Дуусах",
    "Limits" : "Хязгаарууд",
    "STUN included" : "STUN багтсан",
    "Yes" : "Тийм",
    "No" : "Үгүй",
    "TURN included" : "TURN багтсан",
    "Delete the signaling server account" : "Сигнал серверийн бүртгэлийг устгах",
    "_%n user_::_%n users_" : ["%n хэрэглэгч","%n хэрэглэгч"],
    "Installed version: {version}" : "Суулгасан хувилбар: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Nextcloud Talk-ыг бусад үйлчилгээнүүдтэй холбохын тулд Matterbridge суулгаж болно, дэлгэрэнгүй мэдээллийг {linkstart1}GitHub хуудас{linkend}-аас үзнэ үү. Аппыг татаж суулгахад хэсэг хугацаа шаардагдаж болно. Хугацаа хэтэрвэл {linkstart2}Nextcloud App Store{linkend}-оос гараар суулгана уу.",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge binary олдсонгүй эсвэл ажиллуулах боломжгүй.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Та мөн тохиргоогоор дамжуулан Matterbridge хоёртын файлын замыг гараар тохируулж болно. Нэмэлт мэдээллийг {linkstart}Matterbridge нэгтгэлийн баримт бичиг{linkend}-ээс шалгана уу.",
    "Install Talk Matterbridge" : "Talk Matterbridge суулгах",
    "An error occurred while installing the Matterbridge app" : "Matterbridge апп суулгахад алдаа гарлаа",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Talk Matterbridge суулгах явцад алдаа гарлаа. Гараар суулгана уу",
    "Failed to execute Matterbridge binary." : "Matterbridge binary ажиллуулж чадсангүй.",
    "Matterbridge integration" : "Matterbridge нэгтгэл",
    "Enable Matterbridge integration" : "Matterbridge нэгтгэлийг идэвхжүүлэх",
    "Status: Checking connection" : "Төлөв: Холболтыг шалгаж байна",
    "OK: Running version: {version}" : "За: Ажиллаж буй хувилбар: {version}",
    "Error: Server seems to be a Signaling server" : "Алдаа: Сервер Signaling сервер байх бололтой",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Алдаа: Nextcloud сервер болон Бичлэгийн backend серверийн системийн цаг синхрончлогдоогүй байна. Хоёр серверийг цагийн серверт холбох эсвэл цагийг гараар синхрончилно уу.",
    "Recording backend URL" : "Бичлэгийн backend URL",
    "Validate SSL certificate" : "SSL сертификатыг баталгаажуулах",
    "Delete this server" : "Энэ серверийг устгах",
    "Test this server" : "Энэ серверийг тест хийх",
    "Disabled for all calls" : "Бүх дуудлагад идэвхгүй болсон",
    "Enabled for all calls" : "Бүх дуудлагад идэвхтэй",
    "Configurable on conversation level by moderators" : "Модераторууд ярианы түвшинд тохируулж болно",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP-ийн \"upload_max_filesize\" эсвэл \"post_max_size\" тохиргоо нь зөвхөн {maxUpload} хүртэлх хэмжээтэй файл байршуулахыг зөвшөөрнө.",
    "Recording backend settings saved" : "Бичлэгийн backend тохиргоо хадгалагдлаа",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Модераторуудад ярианы түвшинд зөвшөөрөл идэвхжүүлэх боломж олгоно. Энэ яриан дахь дуудлага бүрд нэгдэхийн өмнө оролцогч бүрээс бичлэг хийх зөвшөөрөл шаардагдана.",
    "The consent to be recorded will be required for each participant before joining every call." : "Дуудлага бүрд нэгдэхийн өмнө оролцогч бүрээс бичлэг хийх зөвшөөрөл шаардагдана.",
    "The consent to be recorded is not required." : "Бичигдэх зөвшөөрөл шаардлагагүй.",
    "Recording backend configuration is only possible with a High-performance backend." : "Бичлэгийн backend тохиргоо нь зөвхөн Өндөр гүйцэтгэлтэй backend-тэй хамт боломжтой.",
    "Add a new recording backend server" : "Шинэ бичлэгийн backend сервер нэмэх",
    "Shared secret" : "Хуваалцсан нууц түлхүүр",
    "Recording consent" : "Бичлэгийн зөвшөөрөл",
    "Recording transcription" : "Бичлэгийн транскрипц",
    "Automatically transcribe call recordings with a transcription provider" : "Дуудлагын бичлэгүүдийг транскрипц үйлчилгээ үзүүлэгчээр автоматаар хуулбарлах",
    "Automatically summarize call recordings with transcription and summary providers" : "Хуулбарлалт болон хураангуйн үйлчилгээ үзүүлэгчийн тусламжтай дуудлагын бичлэгүүдийг автоматаар хураангуйл",
    "SIP configuration saved!" : "SIP тохиргоо хадгалагдлаа!",
    "SIP configuration is only possible with a High-performance backend." : "SIP тохиргоо нь зөвхөн Өндөр гүйцэтгэлтэй backend-тэй боломжтой.",
    "Enable SIP Dial-out option" : "SIP залгах сонголтыг идэвхжүүлэх",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "SIP залгах боломжийг дэмжихийн тулд дохионы серверийг шинэчлэх шаардлагатай.",
    "Do not show SIP Dial-out caller number" : "SIP залгах дугаарыг бүү харуулах",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Нэргүй дугаар дуудлага хүлээн авагчид \"тодорхойгүй\" эсвэл \"нуусан дугаар\" гэж харагдах ёстой",
    "Dial-out number" : "Залгах дугаар",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Гарах дуудлагуудад нөөц дуудлага хийгчийн дугаар болгон E164 форматтай дугаар ашиглагдана",
    "Dial-out prefix" : "Залгах угтвар",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Гадагш дуудлагын хэрэглэгчийн дугаарын өмнөх угтвар (өгөгдмөл нь `+`)",
    "Restrict SIP configuration" : "SIP тохиргоог хязгаарлах",
    "Enable SIP configuration" : "SIP тохиргоог идэвхжүүлэх",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Зөвхөн дараах бүлгүүдийн хэрэглэгчид өөрсдийн модераци хийдэг яриануудад SIP-ийг идэвхжүүлж чадна",
    "Phone number (Country)" : "Утасны дугаар (Улс)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Энэ мэдээлэл урилгын и-мэйлээр илгээгдэх бөгөөд бүх оролцогчдод хажуугийн самбарт харуулагдана.",
    "Nextcloud base URL" : "Nextcloud үндсэн URL",
    "Talk Backend URL" : "Talk Backend URL",
    "WebSocket URL" : "WebSocket URL",
    "Available features" : "Боломжит функцууд",
    "Error: Websocket connection failed" : "Алдаа: Websocket холболт амжилтгүй болсон",
    "Error code" : "Алдааны код",
    "Error message" : "Алдааны мессеж",
    "Error: Websocket connection failed. Check browser console" : "Алдаа: Websocket холболт амжилтгүй болсон. Хөтчийн консолыг шалгана уу",
    "High-performance backend URL" : "Өндөр гүйцэтгэлтэй backend URL",
    "Missing High-performance backend warning hidden" : "Өндөр гүйцэтгэлтэй backend дутуу анхааруулга нуугдсан",
    "High-performance backend settings saved" : "Өндөр гүйцэтгэлтэй backend тохиргоо хадгалагдлаа",
    "Nextcloud Talk setup not complete" : "Nextcloud Talk тохиргоо дуусаагүй",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Өндөр гүйцэтгэлтэй backend-гүйгээр 2-оос олон оролцогчтой дуудлагуудад оролцогчид холболтын асуудалтай тулгарах магадлалтай бөгөөд оролцож буй төхөөрөмжүүдэд их ачаалал үүсгэнэ гэдгийг анхаарна уу.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Олон оролцогчтой дуудлагууд жигд ажиллахын тулд Өндөр гүйцэтгэлтэй backend суулгана уу.",
    "Nextcloud portal" : "Nextcloud портал",
    "Quick installation guide" : "Хурдан суулгах заавар",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Олон оролцогчтой дуудлага болон яриануудад Өндөр гүйцэтгэлтэй backend шаардлагатай. Backend-гүйгээр бүх оролцогчид нэг бүрчлэн бусад оролцогч бүрд зориулж өөрсдийн видеог байршуулах шаардлагатай бөгөөд энэ нь холболтын асуудал болон оролцож буй төхөөрөмжүүдэд их ачаалал үүсгэнэ.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Nextcloud Talk-ыг Өндөр гүйцэтгэлтэй backend-тэй ашиглахад тархсан кэш тохируулахыг зөвлөж байна.",
    "Add High-performance backend server" : "Өндөр гүйцэтгэлтэй backend сервер нэмэх",
    "Warn about connectivity issues in calls with more than 2 participants" : "2-оос олон оролцогчтой дуудлагуудад холболтын асуудлын талаар анхааруулах",
    "STUN server URL" : "STUN серверийн URL",
    "The server address is invalid" : "Серверийн хаяг буруу байна",
    "STUN settings saved" : "STUN тохиргоо хадгалагдлаа",
    "STUN servers" : "STUN серверүүд",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN сервер нь чиглүүлэгчийн ард байгаа оролцогчдын нийтийн IP хаягийг тодорхойлоход ашиглагддаг.",
    "Add a new STUN server" : "Шинэ STUN сервер нэмэх",
    "{schema} scheme must be used with a domain" : "{schema} схемийг домайнтай хамт ашиглах ёстой",
    "{option1} and {option2}" : "{option1} болон {option2}",
    "{option} only" : "Зөвхөн {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "За: TURN сервер амжилттай ICE нэр дэвшигчид буцаасан",
    "Error: No working ICE candidates returned by the TURN server" : "Алдаа: TURN сервер ажиллаж байгаа ICE нэр дэвшигч буцаасангүй",
    "Testing whether the TURN server returns ICE candidates" : "TURN сервер ICE нэр дэвшигч буцааж байгаа эсэхийг тест хийж байна",
    "TURN server schemes" : "TURN серверийн схемүүд",
    "TURN server URL" : "TURN серверийн URL",
    "TURN server secret" : "TURN серверийн нууц",
    "TURN server protocols" : "TURN серверийн протоколууд",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN сервер нь галт хана ард байгаа оролцогчдын урсгалыг прокси хийхэд ашиглагддаг. Хэрэв тодорхой оролцогчид бусадтай холбогдож чадахгүй бол TURN сервер шаардлагатай байх магадлалтай. Тохируулах зааврыг {linkstart}энэ баримт бичиг{linkend}-ээс үзнэ үү.",
    "TURN settings saved" : "TURN тохиргоо хадгалагдлаа",
    "TURN servers" : "TURN серверүүд",
    "Add a new TURN server" : "Шинэ TURN сервер нэмэх",
    "Failed" : "Амжилтгүй",
    "OK" : "–æ–∫",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Амжилтгүй: WebAssembly идэвхгүй эсвэл энэ хөтчид дэмжигдэхгүй байна. Шалгалт хийхийн тулд WebAssembly-г идэвхжүүлэх эсвэл дэмждэг хөтөч ашиглана уу.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Амжилтгүй: \".wasm\" болон \".tflite\" файлуудыг вэб сервер зөв буцааж чадсангүй. Talk баримт бичгийн \"Системийн шаардлага\" хэсгийг шалгана уу.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "За: \".wasm\" ба \".tflite\" файлууд веб сервероос зөв буцаагдсан.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "PHP болон Apache тохиргоо нийцэхгүй байна. PHP-ийг зөвхөн MPM_PREFORK модультай, PHP-FPM-ийг зөвхөн MPM_EVENT модультай ашиглах боломжтой гэдгийг анхаарна уу.",
    "Web server setup checks" : "Веб серверийн тохиргооны шалгалтууд",
    "Files required for virtual background can be loaded" : "Виртуал дэвсгэрт шаардлагатай файлуудыг ачаалах боломжтой",
    "Federated user" : "Холбооны хэрэглэгч",
    "Assign participants to rooms" : "Оролцогчдыг өрөөнүүдэд хуваарилах",
    "Configure breakout rooms" : "Салангид өрөөнүүдийг тохируулах",
    "Number of breakout rooms" : "Салангид өрөөнүүдийн тоо",
    "You can create from 1 to 20 breakout rooms." : "Та 1-ээс 20 хүртэл салангид өрөө үүсгэх боломжтой.",
    "Assignment method" : "Хуваарилах арга",
    "Automatically assign participants" : "Оролцогчдыг автоматаар хуваарилах",
    "Manually assign participants" : "Оролцогчдыг гараар хуваарилах",
    "Allow participants to choose" : "Оролцогчдод сонгох боломж олгох",
    "Create rooms" : "Өрөөнүүд үүсгэх",
    "Confirm" : "–ë–∞—Ç–ª–∞—Ö",
    "Create breakout rooms" : "Салангид өрөөнүүд үүсгэх",
    "Reset" : "—Ç–æ—Ö–∏—Ä—É—É–ª–∞—Ö",
    "Delete breakout rooms" : "Салангид өрөөнүүдийг устгах",
    "Room {roomNumber}" : "Өрөө {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Одоогийн салангид өрөөнүүд болон тохиргоо алдагдана",
    "Cancel" : "–±–æ–ª–∏—É–ª–∞—Ö",
    "Unassigned participants" : "Хуваарилагдаагүй оролцогчид",
    "Back" : "–±—É—Ü–∞—Ö",
    "Assign" : "Хуваарилах",
    "Add participant \"{user}\"" : "\"{user}\" оролцогч нэмэх",
    "Now" : "Одоо",
    "Invalid calendar selected" : "Буруу календар сонгосон",
    "Invalid start time selected" : "Буруу эхлэх цаг сонгосон",
    "Invalid end time selected" : "Буруу дуусах цаг сонгосон",
    "Unknown error occurred" : "Үл мэдэгдэх алдаа гарлаа",
    "Sending no invitations" : "Урилга илгээхгүй",
    "{participant0} will receive an invitation" : "{participant0} урилга хүлээн авна",
    "{participant0} and {participant1} will receive invitations" : "{participant0} болон {participant1} урилга хүлээн авна",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} болон %n бусад урилга хүлээн авна","{participant0}, {participant1} болон %n бусад урилга хүлээн авна"],
    "Invite {user}" : "{user}-г урих",
    "Invite all users and emails in this conversation" : "Энэ ярианд байгаа бүх хэрэглэгчид болон имэйлүүдийг урих",
    "Meeting created" : "Уулзалт үүсгэгдлээ",
    "Upcoming meetings" : "Удахгүй болох уулзалтууд",
    "Loading …" : "Ачаалж байна …",
    "No upcoming meetings" : "Удахгүй болох уулзалт байхгүй",
    "Schedule a meeting" : "Уулзалт товлох",
    "Meeting title" : "Уулзалтын гарчиг",
    "From" : "Эхлэх",
    "To" : "Хүртэл",
    "Calendar" : "–ö–∞–ª–µ–Ω–¥–∞—Ä—å",
    "Attendees" : "–û—Ä–æ–ª—Ü–æ–≥—á–∏–¥",
    "No other participants to send invitations to." : "Урилга илгээх өөр оролцогч байхгүй.",
    "Add attendees" : "Оролцогчид нэмэх",
    "Save" : "–•–∞–¥–≥–∞–ª–∞—Ö",
    "Search participants" : "Оролцогчид хайх",
    "No results" : "“Æ—Ä –¥“Ø–Ω –±–∞–π—Ö–≥“Ø–π",
    "Done" : "Дууслаа",
    "Disable live transcription" : "Шууд транскрипцийг идэвхгүй болгох",
    "Disable live translation" : "Шууд орчуулгыг идэвхгүй болгох",
    "Original language: {languageName}" : "Эх хэл: {languageName}",
    "Translated language" : "Орчуулсан хэл",
    "Translated language: {languageName}" : "Орчуулсан хэл: {languageName}",
    "Raise hand" : "Гар өргөх",
    "Raise hand (R)" : "Гар өргөх (R)",
    "Lower hand" : "Гар буулгах",
    "Lower hand (R)" : "Гар буулгах (R)",
    "Exit full screen (F)" : "Бүтэн дэлгэцнээс гарах (F)",
    "Full screen (F)" : "Бүтэн дэлгэц (F)",
    "Speaker view" : "Илтгэгчийн харагдац",
    "Grid view" : "Торон харагдац",
    "Error when trying to load the available live transcription languages" : "Боломжит шууд транскрипц хэлүүдийг ачаалахад алдаа гарлаа",
    "Failed to enable live transcription" : "Шууд транскрипцийг идэвхжүүлж чадсангүй",
    "Failed to enable live translations" : "Шууд орчуулгыг идэвхжүүлж чадсангүй",
    "Failed to disable live translations" : "Шууд орчуулгыг идэвхгүй болгож чадсангүй",
    "Recording consent is required" : "Бичлэгийн зөвшөөрөл шаардлагатай",
    "This conversation is read-only" : "Энэ яриа зөвхөн унших горимд байна",
    "Conversation not found or not joined" : "Яриа олдсонгүй эсвэл нэгдээгүй",
    "Lobby is still active and you're not a moderator" : "Лобби идэвхтэй хэвээр байна, та модератор биш",
    "Connection failed" : "Холболт амжилтгүй",
    "Reload" : "Дахин ачаалах",
    "{nickName} raised their hand." : "{nickName} гараа өргөлөө.",
    "A participant raised their hand." : "Нэг оролцогч гараа өргөлөө.",
    "Collapse stripe" : "Зураасыг хураах",
    "Expand stripe" : "Зураасыг дэлгэх",
    "Previous page of videos" : "Видеоны өмнөх хуудас",
    "Next page of videos" : "Видеоны дараагийн хуудас",
    "Waiting for {user} to join the call" : "{user} дуудлагад нэгдэхийг хүлээж байна",
    "You can invite others in the participant tab of the sidebar" : "Та хажуугийн мөрний оролцогчийн табаас бусдыг урих боломжтой",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Та хажуугийн самбарын оролцогчид табаас бусдыг урих эсвэл энэ холбоосыг хуваалцаж бусдыг урих боломжтой!",
    "Share this link to invite others!" : "Бусдыг урихын тулд энэ холбоосыг хуваалцаарай!",
    "Copy link" : "–•–æ–ª–±–æ–æ—Å —Ö—É—É–ª–∞—Ö",
    "You are not allowed to enable audio" : "Та аудио идэвхжүүлэх эрхгүй байна",
    "No audio. Click to select device" : "Аудио байхгүй. Төхөөрөмж сонгохын тулд дарна уу",
    "Mute audio" : "Аудио хаах",
    "Mute audio (M)" : "Аудио хаах (M)",
    "Unmute audio" : "Аудио нээх",
    "Unmute audio (M)" : "Аудио нээх (M)",
    "None" : "—é—É —á “Ø–≥“Ø–π",
    "Select a microphone" : "Микрофон сонгох",
    "Select a speaker" : "Чанга яригч сонгох",
    "Microphone settings" : "Микрофоны тохиргоо",
    "Check devices" : "Төхөөрөмжүүдийг шалгах",
    "Access to camera was denied" : "Камерт хандах эрхийг татгалзлаа",
    "Error while accessing camera: It is likely in use by another program" : "Камерт хандахад алдаа гарлаа: Өөр програм ашиглаж байх магадлалтай",
    "Error while accessing camera" : "Камерт хандахад алдаа гарлаа",
    "You have been muted by a moderator" : "Модератор таныг хаасан",
    "Hide presenter video" : "Илтгэгчийн видеог нуух",
    "You are not allowed to enable video" : "Та видео идэвхжүүлэх эрхгүй байна",
    "No video. Click to select device" : "Видео байхгүй. Төхөөрөмж сонгохын тулд дарна уу",
    "Disable video" : "Видео идэвхгүй болгох",
    "Disable video (V)" : "Видео идэвхгүй болгох (V)",
    "Enable video" : "Видео идэвхжүүлэх",
    "Enable video (V)" : "Видео идэвхжүүлэх (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Видео идэвхжүүлэх - Видеог анх удаа идэвхжүүлэхэд таны холболт түр тасрах болно",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Видео идэвхжүүлэх (V) - Видеог анх удаа идэвхжүүлэхэд таны холболт түр тасрах болно",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Видео идэвхжүүлэх. Видеог анх удаа идэвхжүүлэхэд таны холболт түр тасрах болно",
    "Select a video device" : "Видео төхөөрөмж сонгох",
    "Show presenter" : "Илтгэгчийг харуулах",
    "You" : "Та",
    "Mute" : "Хаах",
    "Muted" : "Хаагдсан",
    "Show screen" : "Дэлгэц харуулах",
    "Stop following" : "Дагахаа зогсоох",
    "Collapse" : "Хураах",
    "Expand" : "Дэлгэх",
    "You need to be logged in to upload files" : "Файл байршуулахын тулд нэвтрэх шаардлагатай",
    "Drop your files to upload" : "Файлуудаа байршуулахын тулд энд тавина уу",
    "Conversation messages" : "Ярианы мессежүүд",
    "Scroll to bottom" : "Доош гүйлгэх",
    "Post message" : "Мессеж илгээх",
    "Federated conversation" : "Федерацийн яриа",
    "Public conversation" : "Нийтийн яриа",
    "Favorite" : "–î—É—Ä—Ç–∞–π",
    "Banned users" : "Хориглогдсон хэрэглэгчид",
    "Manage the list of banned users in this conversation." : "Энэ ярианд хориглогдсон хэрэглэгчдийн жагсаалтыг удирдах.",
    "Manage bans" : "Хориглолтуудыг удирдах",
    "No banned users" : "Хориглогдсон хэрэглэгч байхгүй",
    "Banned by:" : "Хориглосон:",
    "Date:" : "–û–≥–Ω–æ–æ:",
    "Note:" : "Тэмдэглэл:",
    "Hide details" : "Дэлгэрэнгүйг нуух",
    "Show details" : "Дэлгэрэнгүйг харуулах",
    "Unban" : "Хориг тайлах",
    "Error while updating conversation name" : "Ярианы нэр шинэчлэхэд алдаа гарлаа",
    "Error while updating conversation description" : "Ярианы тодорхойлолт шинэчлэхэд алдаа гарлаа",
    "Enter a name for this conversation" : "Энэ яриаг нэрлэнэ үү",
    "Edit conversation name" : "Ярианы нэр засах",
    "Edit conversation description" : "Ярианы тодорхойлолт засах",
    "Enter a description for this conversation" : "Энэ ярианы тодорхойлолт оруулна уу",
    "Picture" : "Зураг",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Дараах ботуудыг энэ яриад идэвхжүүлж болно. Энэ серверт илүү олон бот суулгуулахын тулд администрацитайгаа холбогдоно уу.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Энэ серверт ямар ч бот суулгагдаагүй байна. Бот суулгуулахын тулд администрацитайгаа холбогдоно уу.",
    "Disable" : "Идэвхгүй болгох",
    "Enable" : "Идэвхжүүлэх",
    "Breakout rooms" : "Салангид өрөөнүүд",
    "Manage breakout rooms" : "Салангид өрөөнүүдийг удирдах",
    "Set up breakout rooms for this conversation" : "Энэ яриад салангид өрөөнүүд тохируулах",
    "Please select a valid PNG or JPG file" : "Хүчинтэй PNG эсвэл JPG файл сонгоно уу",
    "Choose your conversation picture" : "Ярианы зургаа сонгоно уу",
    "Choose" : "–°–æ–Ω–≥–æ—Ö",
    "Error setting conversation picture" : "Ярианы зураг тохируулахад алдаа гарлаа",
    "Could not set the conversation picture: {error}" : "Ярианы зургийг тохируулж чадсангүй: {error}",
    "Error cropping conversation picture" : "Ярианы зургийг тайрахад алдаа гарлаа",
    "Error removing conversation picture" : "Ярианы зургийг арилгахад алдаа гарлаа",
    "Set emoji as conversation picture" : "Эможийг ярианы зураг болгох",
    "Set background color for conversation picture" : "Ярианы зургийн дэвсгэр өнгө тохируулах",
    "Upload conversation picture" : "Ярианы зураг байршуулах",
    "Choose conversation picture from files" : "Файлуудаас ярианы зураг сонгох",
    "Remove conversation picture" : "Ярианы зургийг арилгах",
    "The file must be a PNG or JPG" : "Файл PNG эсвэл JPG байх ёстой",
    "Set picture" : "Зураг тохируулах",
    "Default permissions modified for {conversationName}" : "{conversationName}-ийн өгөгдмөл зөвшөөрлүүд өөрчлөгдлөө",
    "Could not modify default permissions for {conversationName}" : "{conversationName}-ийн өгөгдмөл зөвшөөрлүүдийг өөрчлөх боломжгүй",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Энэ ярианы оролцогчдын анхдагч зөвшөөрлүүдийг засварла. Эдгээр тохиргоо модераторуудад нөлөөлөхгүй.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Энэ хэсэгт зөвшөөрлүүдийг өөрчлөх бүрд тодорхой оролцогчдод өмнө нь олгогдсон тусгай зөвшөөрлүүд устах болно.",
    "All permissions" : "Бүх зөвшөөрөл",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Оролцогчид дуудлага эхлүүлэх, дуудлагад нэгдэх, аудио болон видео идэвхжүүлэх, дэлгэц хуваалцах зөвшөөрөлтэй.",
    "Restricted" : "–•—è–∑–≥–∞–∞—Ä–ª–∞–≥–¥—Å–∞–Ω",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Оролцогчид дуудлагад нэгдэх боломжтой боловч модератор гараар зөвшөөрөл олгох хүртэл аудио, видео идэвхжүүлэх, дэлгэц хуваалцах боломжгүй.",
    "Advanced permissions" : "Нарийвчилсан зөвшөөрлүүд",
    "Edit permissions" : "Зөвшөөрлүүд засах",
    "Conversation settings" : "Ярианы тохиргоо",
    "Basic Info" : "Үндсэн мэдээлэл",
    "Personal" : "–•—É–≤–∏–π–Ω",
    "Moderation" : "Модераци",
    "Setup overview" : "Тохиргооны тойм",
    "Live transcription" : "Шууд транскрипц",
    "Enable live transcription" : "Шууд транскрипцийг идэвхжүүлэх",
    "Breakout Rooms" : "Салангид өрөөнүүд",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Ботууд",
    "Danger zone" : "Аюултай бүс",
    "Archive conversation" : "Яриаг архивлах",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Архивлагдсан яриа анхдагчаар ярианы жагсаалтаас нуугддаг. Гэхдээ ярианы нэрээр хайх эсвэл архивлагдсан ярианы жагсаалтад хандахад харагдах болно.",
    "Do you really want to leave \"{displayName}\"?" : "Та үнэхээр \"{displayName}\" яриаг орхих уу?",
    "You can archive this conversation instead." : "Та оронд нь энэ яриаг архивлаж болно.",
    "Leave conversation" : "Яриаг орхих",
    "You need to promote a new moderator before you can leave the conversation" : "Яриаг орхихын өмнө шинэ модератор дэвшүүлэх шаардлагатай",
    "Delete conversation" : "Яриаг устгах",
    "Do you really want to delete \"{displayName}\"?" : "Та үнэхээр \"{displayName}\" яриаг устгах уу?",
    "Error while deleting conversation" : "Яриаг устгахад алдаа гарлаа",
    "Delete all chat messages" : "Бүх чат мессежийг устгах",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Та үнэхээр \"{displayName}\" ярианы бүх мессежийг устгах уу?",
    "Error while clearing chat history" : "Чатын түүхийг цэвэрлэхэд алдаа гарлаа",
    "Be careful, these actions cannot be undone." : "Болгоомжтой байгаарай, эдгээр үйлдлийг буцаах боломжгүй.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Яриаг орхисны дараа хаалттай яриад дахин нэгдэхэд урилга шаардлагатай. Нээлттэй яриад хэдийд ч дахин нэгдэж болно.",
    "Permanently delete this conversation." : "Энэ яриаг бүрмөсөн устгах.",
    "Delete chat messages" : "Чат мессежийг устгах",
    "Permanently delete all the messages in this conversation." : "Энэ ярианы бүх мессежийг бүрмөсөн устгах.",
    "_%n hour_::_%n hours_" : ["%n цаг","%n цаг"],
    "_%n day_::_%n days_" : ["%n өдөр","%n өдөр"],
    "_%n week_::_%n weeks_" : ["%n долоо хоног","%n долоо хоног"],
    "Custom expiration time" : "Тусгай дуусах хугацаа",
    "Message expiration disabled" : "Мессежийн дуусах хугацаа идэвхгүй болсон",
    "Message expiration set: {duration}" : "Мессежийн дуусах хугацаа тохируулагдсан: {duration}",
    "Error when trying to set message expiration" : "Мессежийн дуусах хугацаа тохируулахад алдаа гарлаа",
    "Message expiration" : "Мессежийн дуусах хугацаа",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Чат мессежүүд тодорхой хугацааны дараа хугацаа дуусч болно. Тэмдэглэл: Чатад хуваалцсан файлууд эзэмшигчийн хувьд устахгүй, гэхдээ яриан дотор хуваалцагдахаа болино.",
    "Set message expiration" : "Мессежийн дуусах хугацаа тохируулах",
    "Current message expiration" : "Одоогийн мессежийн дуусах хугацаа",
    "Password copied to clipboard" : "Нууц үг санах ойд хуулагдлаа",
    "Password could not be copied" : "Нууц үгийг хуулж чадсангүй",
    "Guest access" : "Зочны хандалт",
    "Breakout rooms are not allowed in public conversations." : "Нийтийн яриануудад салангид өрөөнүүд зөвшөөрөгдөхгүй.",
    "Allow guests to join this conversation via link" : "Зочдод холбоосоор энэ яриад нэгдэхийг зөвшөөрөх",
    "Password protection" : "Password protection",
    "This conversation is password-protected. Guests need password to join" : "Энэ яриа нууц үгээр хамгаалагдсан. Зочид нэгдэхэд нууц үг хэрэгтэй",
    "Password protection is needed for public conversations" : "Нийтийн яриануудад нууц үгээр хамгаалалт шаардлагатай",
    "Set a password" : "Нууц үг тохируулах",
    "Change password" : "Нууц үг өөрчлөх",
    "Enter new password" : "Шинэ нууц үг оруулах",
    "Save password" : "Нууц үг хадгалах",
    "Copy password" : "Нууц үг хуулах",
    "Guests are allowed to join this conversation via link" : "Зочдод холбоосоор энэ яриад нэгдэх зөвшөөрөгдсөн",
    "Guests are not allowed to join this conversation" : "Зочдод энэ яриад нэгдэх зөвшөөрөгдөөгүй",
    "Resend invitations" : "Урилга дахин илгээх",
    "This conversation is open to both registered users and users created with the Guests app" : "Энэ яриа бүртгэлтэй хэрэглэгчид болон Guests аппаар үүсгэсэн хэрэглэгчдэд нээлттэй",
    "This conversation is open to registered users" : "Энэ яриа бүртгэлтэй хэрэглэгчдэд нээлттэй",
    "This conversation is limited to the current participants" : "Энэ яриа одоогийн оролцогчдоор хязгаарлагдсан",
    "You opened the conversation to both registered users and users created with the Guests app" : "Та яриаг бүртгэлтэй хэрэглэгчид болон Guests аппаар үүсгэсэн хэрэглэгчдэд нээсэн",
    "Error occurred when opening or limiting the conversation" : "Яриаг нээх эсвэл хязгаарлахад алдаа гарлаа",
    "Open conversation to registered users, showing it in search results" : "Бүртгэлтэй хэрэглэгчдэд яриа нээх, хайлтын үр дүнд харуулах",
    "Also open to users created with the Guests app" : "Мөн Зочин апп-аар үүсгэсэн хэрэглэгчдэд нээлттэй",
    "Open conversation" : "Яриа нээх",
    "Set language spoken in calls" : "Дуудлагад ярих хэлийг тохируулах",
    "Languages could not be loaded" : "Хэлүүдийг ачаалж чадсангүй",
    "Invalid language" : "Буруу хэл",
    "Default language (English)" : "Өгөгдмөл хэл (Англи)",
    "Default live transcription language set" : "Өгөгдмөл шууд транскрипцийн хэл тохируулагдлаа",
    "Live transcription language set: {languageName}" : "Шууд транскрипцийн хэл тохируулагдсан: {languageName}",
    "Error when trying to set live transcription language" : "Шууд транскрипцийн хэл тохируулахад алдаа гарлаа",
    "Start time: {date}" : "Эхлэх цаг: {date}",
    "Start time has been updated" : "Эхлэх цаг шинэчлэгдлээ",
    "Error occurred while updating start time" : "Эхлэх цагийг шинэчлэхэд алдаа гарлаа",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Лобби идэвхжүүлснээр модератор биш хүмүүсийг явагдаж буй дуудлагаас хасна.",
    "Enable lobby, restricting the conversation to moderators" : "Лобби идэвхжүүлж, яриаг модераторуудаар хязгаарлах",
    "Meeting start time" : "Уулзалтын эхлэх цаг",
    "Start time (optional)" : "Эхлэх цаг (заавал биш)",
    "Import email participants" : "Имэйл оролцогчдыг импортлох",
    "You can import a list of email participants from a CSV file." : "Та CSV файлаас имэйл оролцогчдын жагсаалтыг импортлож болно.",
    "Poll drafts" : "Санал асуулгын ноорогууд",
    "Browse poll drafts" : "Санал асуулгын нооргуудыг үзэх",
    "Error occurred when locking the conversation" : "Яриаг түгжихэд алдаа гарлаа",
    "Error occurred when unlocking the conversation" : "Ярианы түгжээг тайлахад алдаа гарлаа",
    "Lock conversation" : "Яриаг түгжих",
    "This will also terminate the ongoing call." : "Энэ мөн явагдаж буй дуудлагыг дуусгана.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Хэн ч мессеж бичих эсвэл дуудлага эхлүүлэхээс сэргийлж яриаг түгж",
    "Edit" : "–∑–∞—Å–≤–∞—Ä–ª–∞—Ö",
    "More information" : "Дэлгэрэнгүй мэдээлэл",
    "Delete" : "–£—Å—Ç–≥–∞—Ö",
    "Add new bridged channel to current conversation" : "Одоогийн яриад шинэ гүүр суваг нэмэх",
    "unknown state" : "үл мэдэгдэх төлөв",
    "running" : "ажиллаж байна",
    "not running, check Matterbridge log" : "ажиллаагүй байна, Matterbridge логоо шалгана уу",
    "not running" : "ажиллаагүй байна",
    "Bridge saved" : "Гүүр хадгалагдлаа",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Matterbridge-ийн тусламжтай янз бүрийн шуурхай мессежийн системүүдийн сувгуудыг холбож болно.",
    "More info on Matterbridge" : "Matterbridge-ийн талаар дэлгэрэнгүй",
    "Messaging systems" : "Мессежийн системүүд",
    "Enable bridge" : "Гүүрийг идэвхжүүлэх",
    "Show Matterbridge log" : "Matterbridge лог харуулах",
    "Log content" : "Логын агуулга",
    "Only moderators are allowed to mention @all" : "Зөвхөн модераторууд @all дурдах эрхтэй",
    "All participants are allowed to mention @all" : "Бүх оролцогчид @all дурдах эрхтэй",
    "Participants are now allowed to mention @all." : "Оролцогчдод одоо @all дурдах зөвшөөрөгдлөө.",
    "Mentioning @all has been limited to moderators." : "@all дурдахыг модераторуудаар хязгаарлалаа.",
    "Allow participants to mention @all" : "Оролцогчдод @all дурдахыг зөвшөөрөх",
    "Mention permissions" : "Дурдах зөвшөөрлүүд",
    "Notifications" : "–ú—ç–¥—ç–≥–¥—ç–ª",
    "Notify about calls in this conversation" : "Энэ ярианы дуудлагуудын талаар мэдэгдэх",
    "Important conversation" : "Чухал яриа",
    "\"Do not disturb\" user status is ignored for important conversations" : "Чухал яриануудад \"Бүү саад бол\" хэрэглэгчийн төлөвийг үл хэрэгсэнэ",
    "Sensitive conversation" : "Мэдрэмтгий яриа",
    "Message preview will be disabled in conversation list and notifications" : "Мессежийн урьдчилсан харагдац ярианы жагсаалт болон мэдэгдлүүдэд идэвхгүй болно",
    "Recording consent is required for calls in this conversation" : "Энэ ярианы дуудлагуудад бичлэгийн зөвшөөрөл шаардлагатай",
    "Recording consent is not required for calls in this conversation" : "Энэ ярианы дуудлагуудад бичлэгийн зөвшөөрөл шаардлагагүй",
    "Recording consent requirement was updated" : "Бичлэгийн зөвшөөрлийн шаардлага шинэчлэгдлээ",
    "Error occurred while updating recording consent" : "Бичлэгийн зөвшөөрлийг шинэчлэхэд алдаа гарлаа",
    "Recording Consent" : "Бичлэгийн зөвшөөрөл",
    "Recording consent cannot be changed once a call or breakout session has started." : "Дуудлага эсвэл салангид хуралдаан эхэлсний дараа бичлэгийн зөвшөөрлийг өөрчлөх боломжгүй.",
    "Require recording consent before joining call in this conversation" : "Энэ ярианы дуудлагад нэгдэхээс өмнө бичлэгийн зөвшөөрөл шаардах",
    "Recording consent is required for all calls" : "Бүх дуудлагад бичлэгийн зөвшөөрөл шаардлагатай",
    "SIP dial-in is now possible without PIN requirement" : "PIN шаардлагагүйгээр SIP залгах боломжтой болсон",
    "SIP dial-in is now enabled" : "SIP залгалт одоо идэвхжлээ",
    "SIP dial-in is now disabled" : "SIP залгалт одоо идэвхгүй болсон",
    "Error occurred when enabling SIP dial-in" : "SIP залгалтыг идэвхжүүлэхэд алдаа гарлаа",
    "Error occurred when disabling SIP dial-in" : "SIP залгалтыг идэвхгүй болгоход алдаа гарлаа",
    "Phone and SIP dial-in" : "Утас болон SIP залгалт",
    "Enable phone and SIP dial-in" : "Утас болон SIP залгалтыг идэвхжүүлэх",
    "Allow to dial-in without a PIN" : "PIN-гүйгээр залгахыг зөвшөөрөх",
    "Ongoing" : "Үргэлжилж байна",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n хүн зөвшөөрсөн","%n хүн зөвшөөрсөн"],
    "_%n person declined_::_%n people declined_" : ["%n хүн татгалзсан","%n хүн татгалзсан"],
    "_and %n other attachment_::_and %n other attachments_" : ["болон %n бусад хавсралт","болон %n бусад хавсралт"],
    "With {displayName}" : "{displayName}-тай",
    "In {conversation}" : "{conversation} яриад",
    "View attachment" : "Хавсралт харах",
    "Join" : "Нэгдэх",
    "View conversation" : "Яриа харах",
    "View event on Calendar" : "Календарт арга хэмжээ харах",
    "Error while creating the conversation" : "Яриа үүсгэхэд алдаа гарлаа",
    "Hello, {displayName}" : "Сайн байна уу, {displayName}",
    "Start meeting now" : "Уулзалтыг одоо эхлүүлэх",
    "Give your meeting a title" : "Уулзалтынхаа гарчгийг оруулна уу",
    "Create and copy link" : "Үүсгэж холбоос хуулах",
    "Create a new conversation" : "Шинэ яриа үүсгэх",
    "Join open conversations" : "Нээлттэй яриануудад нэгдэх",
    "Call a phone number" : "Утасны дугаар руу залгах",
    "Scroll backward" : "Арагш гүйлгэх",
    "Scroll forward" : "Урагш гүйлгэх",
    "Schedule meetings" : "Уулзалтууд товлох",
    "You don't have any upcoming meetings" : "Танд удахгүй болох уулзалт байхгүй",
    "Open calendar" : "Календар нээх",
    "Unread mentions" : "Уншаагүй дурдалтууд",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Таныг дурдсан мессежүүд энд харагдана. @ бичээд нэрийг нь оруулж хүмүүсийг дурдаж болно",
    "Upcoming reminders" : "Удахгүй болох сануулгууд",
    "Message reminders" : "Мессежийн сануулгууд",
    "Set a reminder on a message to be notified" : "Мэдэгдэл авахын тулд мессеж дээр сануулга тохируулах",
    "Start a group conversation" : "Бүлгийн яриа эхлүүлэх",
    "Create conversation" : "Яриа үүсгэх",
    "Enter your name" : "Нэрээ оруулна уу",
    "Submit name and join" : "Нэр илгээж нэгдэх",
    "Do you already have an account?" : "Танд аль хэдийн бүртгэл байна уу?",
    "Log in" : "–ù—ç–≤—Ç—Ä—ç—Ö",
    "Error while verifying uploaded file" : "Байршуулсан файлыг баталгаажуулахад алдаа гарлаа",
    "Uploaded file is verified" : "Байршуулсан файл баталгаажлаа",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Агуулгын формат нь таслалаар тусгаарлагдсан утгууд (CSV):<br/>- Толгой мөр шаардлагатай бөгөөд <samp>\"name\",\"email\"</samp> эсвэл зөвхөн <samp>\"email\"</samp> байх ёстой<br/>- Мөр бүрт нэг оруулга (жишээ нь <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "Оролцогчид амжилттай нэмэгдлээ",
    "Error while adding participants" : "Оролцогчид нэмэхэд алдаа гарлаа",
    "Import a file" : "Файл импортлох",
    "Browse" : "Хайх",
    "This might take a moment" : "Энэ хэсэг хугацаа шаардаж болно",
    "Send invitations" : "Урилга илгээх",
    "_%n invalid email_::_%n invalid emails_" : ["%n буруу имэйл","%n буруу имэйл"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n имэйл аль хэдийн импортлогдсон эсвэл давхардсан","%n имэйл аль хэдийн импортлогдсон эсвэл давхардсан"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n урилга илгээх боломжтой","%n урилга илгээх боломжтой"],
    "An error occurred while calling a phone number" : "Утасны дугаар руу залгахад алдаа гарлаа",
    "Phone number could not be called: {error}" : "Утасны дугаар руу залгах боломжгүй: {error}",
    "Phone number could not be called" : "Утасны дугаар руу залгах боломжгүй",
    "Search participants or phone numbers" : "Оролцогчид эсвэл утасны дугаар хайх",
    "Mark as read" : "Уншсан гэж тэмдэглэх",
    "Mark as unread" : "Уншаагүй гэж тэмдэглэх",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Unarchive conversation" : "Архиваас гаргах",
    "Ignore \"Do not disturb\"" : "\"Бүү саад бол\"-ыг үл хэрэгсэх",
    "You need to promote a new moderator before you can leave the conversation." : "Яриаг орхихын өмнө шинэ модератор дэвшүүлэх шаардлагатай.",
    "Conversation actions" : "Ярианы үйлдлүүд",
    "Notify about calls" : "Дуудлагуудын талаар мэдэгдэх",
    "Hide message text" : "Мессежийн текстийг нуух",
    "Pending invitations" : "Хүлээгдэж буй урилгууд",
    "From {user} at {remoteServer}" : "{remoteServer}-ийн {user}-аас",
    "Decline invitation" : "Урилгаас татгалзах",
    "Accept invitation" : "Урилга хүлээн авах",
    "No pending invitations" : "Хүлээгдэж буй урилга байхгүй",
    "Home" : "–ù“Ø“Ø—Ä",
    "Unread" : "Уншаагүй",
    "Mentions" : "Дурдалтууд",
    "Meetings" : "Уулзалтууд",
    "Alphabetically" : "Цагаан толгойн дарааллаар",
    "No followed threads" : "Дагасан thread байхгүй",
    "No matches found" : "Тохирох зүйл олдсонгүй",
    "No conversations found" : "Яриа олдсонгүй",
    "You have no archived conversations." : "Танд архивлагдсан яриа байхгүй.",
    "Subscribe to an existing thread or start your own." : "Одоо байгаа thread-д бүртгүүлэх эсвэл өөрийнхөө thread эхлүүлэх.",
    "You have no unread mentions." : "Танд уншаагүй дурдалт байхгүй.",
    "You have no unread messages." : "Танд уншаагүй мессеж байхгүй.",
    "An error occurred while performing the search" : "Хайлт хийхэд алдаа гарлаа",
    "Conversation list" : "Ярианы жагсаалт",
    "Filter conversations by" : "Яриануудыг шүүх",
    "Unread messages" : "Уншаагүй мессежүүд",
    "Meeting conversations" : "Уулзалтын яриануудууд",
    "Clear filters" : "Шүүлтүүр арилгах",
    "New personal note" : "Шинэ хувийн тэмдэглэл",
    "Back to conversations" : "Яриануудруу буцах",
    "Archived conversations" : "Архивлагдсан яриануудууд",
    "Threads" : "Thread-үүд",
    "Clear filter" : "Шүүлтүүр арилгах",
    "Show more threads" : "Илүү олон thread харуулах",
    "App settings" : "Апп тохиргоо",
    "Users" : "—Ö—ç—Ä—ç–≥–ª—ç–≥—á",
    "Groups" : "–±“Ø–ª—ç–≥“Ø“Ø–¥",
    "Teams" : "Багууд",
    "Federated users" : "Федерацийн хэрэглэгчид",
    "New private conversation" : "Шинэ хувийн яриа",
    "Other sources" : "Бусад эх үүсвэрүүд",
    "Open conversations" : "Нээлттэй яриануудууд",
    "No search results" : "Хайлтын үр дүн байхгүй",
    "Users, groups and teams" : "Хэрэглэгчид, бүлгүүд болон багууд",
    "Users and groups" : "Хэрэглэгчид болон бүлгүүд",
    "Users and teams" : "Хэрэглэгчид болон багууд",
    "Groups and teams" : "Бүлгүүд болон багууд",
    "New group conversation" : "Шинэ бүлгийн яриа",
    "The meeting will start soon" : "Уулзалт удахгүй эхэлнэ",
    "This meeting is scheduled for {startTime}" : "Энэ уулзалт {startTime}-д товлогдсон",
    "You are currently waiting in the lobby" : "Та одоо лоббид хүлээж байна",
    "Enable noise suppression" : "Дуу чимээ дарагчийг идэвхжүүлэх",
    "Reduce background noises for better voice quality" : "Дуу хоолойн чанарыг сайжруулахын тулд арын дуу чимээг бууруулах",
    "Enable echo cancellation" : "Цуурайн арилгалтыг идэвхжүүлэх",
    "Minimize echo effect from own surrounding" : "Орчны цуурайн нөлөөг багасгах",
    "Enable auto gain control" : "Автомат олшруулалтын хяналтыг идэвхжүүлэх",
    "Dynamically adjust microphone volume for consistent level" : "Тогтвортой түвшин хадгалахын тулд микрофоны дууны хэмжээг автоматаар тохируулах",
    "Select microphone" : "Микрофон сонгох",
    "No microphone available" : "Микрофон байхгүй",
    "Select speaker" : "Чанга яригч сонгох",
    "No speaker available" : "Чанга яригч байхгүй",
    "Select camera" : "Камер сонгох",
    "No camera available" : "Камер байхгүй",
    "Select a device" : "Төхөөрөмж сонгох",
    "Test speakers" : "Чанга яригчийг тест хийх",
    "Test" : "Тест",
    "Devices" : "–¢”©—Ö”©”©—Ä”©–º–∂“Ø“Ø–¥",
    "Backgrounds" : "Дэвсгэрүүд",
    "No audio" : "Аудио байхгүй",
    "No camera" : "Камер байхгүй",
    "Display video as you will see it (mirrored)" : "Видеог таны харах байдлаар харуулах (толь)",
    "Display video as others will see it" : "Видеог бусдын харах байдлаар харуулах",
    "Calls are not supported in your browser" : "Таны хөтөч дуудлагыг дэмжихгүй",
    "Access to microphone is only possible with HTTPS" : "Микрофонд хандах нь зөвхөн HTTPS-ээр боломжтой",
    "Access to microphone was denied" : "Микрофонд хандах эрхийг татгалзлаа",
    "Error while accessing microphone" : "Микрофонд хандахад алдаа гарлаа",
    "Access to camera is only possible with HTTPS" : "Камерт хандах нь зөвхөн HTTPS-ээр боломжтой",
    "The call is being recorded." : "Дуудлага бичигдэж байна.",
    "The call might be recorded." : "Дуудлага бичигдэж байж болзошгүй.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Бичлэг нь таны дуу, камерын видео болон дэлгэц хуваалцалтыг агуулж болно. Дуудлагад нэгдэхийн өмнө таны зөвшөөрөл шаардлагатай.",
    "Give consent to the recording of this call" : "Энэ дуудлагын бичлэгийг зөвшөөрөх",
    "Show more info" : "Дэлгэрэнгүй мэдээлэл харуулах",
    "Audio is not available" : "Аудио боломжгүй",
    "Video is not available" : "Видео боломжгүй",
    "Start recording immediately with the call" : "Дуудлагын хамт шууд бичлэг эхлүүлэх",
    "Notify all participants about this call" : "Бүх оролцогчдод энэ дуудлагын талаар мэдэгдэх",
    "Apply settings" : "Тохиргоог хэрэглэх",
    "Select virtual office background" : "Виртуал оффисын дэвсгэр сонгох",
    "Select virtual home background" : "Виртуал гэрийн дэвсгэр сонгох",
    "Select virtual abstract background" : "Виртуал хийсвэр дэвсгэр сонгох",
    "Select virtual beach background" : "Виртуал далайн эрэг дэвсгэр сонгох",
    "Select virtual park background" : "Виртуал цэцэрлэгт хүрээлэн дэвсгэр сонгох",
    "Select virtual theater background" : "Виртуал театр дэвсгэр сонгох",
    "Select virtual library background" : "Виртуал номын сан дэвсгэр сонгох",
    "Select virtual space station background" : "Виртуал сансрын станц дэвсгэр сонгох",
    "Error while uploading the file" : "Файл байршуулахад алдаа гарлаа",
    "Select a file" : "Файл сонгох",
    "Invalid path selected" : "Буруу зам сонгосон",
    "Select virtual background from file {fileName}" : "{fileName} файлаас виртуал дэвсгэр сонгох",
    "Blur" : "Бүдэгрүүлэх",
    "Upload" : "–±–∞–π—Ä—à—É—É–ª–∞—Ö",
    "Files" : "—Ñ–∞–π–ª—É—É–¥",
    "(editing)" : "(засаж байна)",
    "(edited)" : "(засагдсан)",
    "The message has expired or has been deleted" : "Мессеж дууссан эсвэл устгагдсан",
    "Cancel quote" : "Ишлэлийг болих",
    "24 hours" : "24 —Ü–∞–≥",
    "7 days" : "7 хоног",
    "30 days" : "30 хоног",
    "Until unpin" : "Бэхлэлт тайлах хүртэл",
    "Edited by {actor}" : "{actor} засварласан",
    "Pinned by you" : "Та бэхлэсэн",
    "Pinned by {actor}" : "{actor} бэхлэсэн",
    "Until {absoluteDate}" : "{absoluteDate} хүртэл",
    "Message text copied to clipboard" : "Мессежийн текст санах ойд хуулагдлаа",
    "Message text could not be copied" : "Мессежийн текстийг хуулж чадсангүй",
    "Message forwarded to \"Note to self\"" : "Мессеж \"Өөртөө тэмдэглэл\" рүү дамжуулагдлаа",
    "Error while forwarding message to \"Note to self\"" : "Мессежийг \"Өөртөө тэмдэглэл\" рүү дамжуулахад алдаа гарлаа",
    "A reminder was successfully removed" : "Сануулга амжилттай арилгагдлаа",
    "Error occurred when removing a reminder" : "Сануулга арилгахад алдаа гарлаа",
    "A reminder was successfully set at {datetime}" : "Сануулга {datetime}-д амжилттай тохируулагдлаа",
    "Error occurred when creating a reminder" : "Сануулга үүсгэхэд алдаа гарлаа",
    "Add a reaction to this message" : "Энэ мессежид хариу үйлдэл нэмэх",
    "Reply" : "—Ö–∞—Ä–∏—É–ª—Ç",
    "More actions" : "Нэмэлт үйлдлүүд",
    "Set reminder" : "Сануулга тохируулах",
    "Pin message" : "Мессеж бэхлэх",
    "Unpin message" : "Мессеж бэхлэлт тайлах",
    "Reply privately" : "Хувийн хариулах",
    "Edit message" : "Мессеж засах",
    "Copy message" : "Мессеж хуулах",
    "Copy message link" : "Мессеж холбоос хуулах",
    "Go to file" : "Файл руу очих",
    "Download file" : "Файл татах",
    "Go to thread" : "Thread руу очих",
    "Edit thread details" : "Thread дэлгэрэнгүйг засах",
    "Forward message" : "Мессеж дамжуулах",
    "Translate" : "–û—Ä—á—É—É–ª–≥–∞",
    "Set custom reminder" : "Тусгай сануулга тохируулах",
    "Keep pinned for" : "Бэхлэгдсэн байх хугацаа",
    "Set custom period" : "Тусгай хугацаа тохируулах",
    "Close reactions menu" : "Хариу үйлдлийн цэсийг хаах",
    "React with {emoji}" : "{emoji}-ээр хариу үзүүлэх",
    "React with another emoji" : "Өөр эможигоор хариу үзүүлэх",
    "Choose a conversation to forward the selected message." : "Сонгосон мессежийг дамжуулах яриа сонгоно уу.",
    "Error while forwarding message" : "Мессеж дамжуулахад алдаа гарлаа",
    "The message has been forwarded to {selectedConversationName}" : "Мессеж {selectedConversationName} руу дамжуулагдлаа",
    "Dismiss" : "–ê—Ä–∏–ª–≥–∞—Ö",
    "Go to conversation" : "Яриа руу очих",
    "Detect language" : "Хэл илрүүлэх",
    "The message could not be translated" : "Мессежийг орчуулж чадсангүй",
    "Translation copied to clipboard" : "Орчуулга санах ойд хуулагдлаа",
    "Translation could not be copied" : "Орчуулгыг хуулж чадсангүй",
    "Translate message" : "Мессеж орчуулах",
    "Source language to translate from" : "Орчуулах эх хэл",
    "Translate from" : "Орчуулах хэл",
    "Target language to translate into" : "Орчуулах зорилтот хэл",
    "Translate to" : "Орчуулах хэл",
    "Translating" : "Орчуулж байна",
    "Copy translated text" : "Орчуулсан текстийг хуулах",
    "Error when scheduling the message" : "Мессеж товлоход алдаа гарлаа",
    "Reschedule" : "Дахин товлох",
    "Send now" : "Одоо илгээх",
    "Choose a time" : "Цаг сонгох",
    "Send at custom time" : "Тусгай цагт илгээх",
    "Will be sent without notification" : "Мэдэгдэлгүй илгээгдэнэ",
    "Message read by everyone who shares their reading status" : "Унших төлөвөө хуваалцдаг бүгд мессежийг уншсан",
    "Message sent" : "Мессеж илгээгдсэн",
    "Sent without notification" : "Мэдэгдэлгүй илгээгдсэн",
    "Deleting message" : "Мессеж устгаж байна",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Мессеж амжилттай устгагдсан, гэхдээ бот эсвэл Matterbridge тохируулагдсан тул мессеж аль хэдийн бусад үйлчилгээнүүд рүү тархсан байж болно",
    "Message deleted successfully" : "Мессеж амжилттай устгагдлаа",
    "Message could not be deleted because it is too old" : "Мессеж хэт хуучин учраас устгах боломжгүй",
    "Only normal chat messages can be deleted" : "Зөвхөн энгийн чат мессежийг устгах боломжтой",
    "An error occurred while deleting the message" : "Мессеж устгахад алдаа гарлаа",
    "Pinned" : "Бэхлэгдсэн",
    "Your browser does not support playing audio files" : "Таны хөтөч аудио файл тоглуулахыг дэмжихгүй",
    "Contact" : "Холбоо барих",
    "{stack} in {board}" : "{board} дахь {stack}",
    "Deck Card" : "Deck карт",
    "Remove {fileName}" : "{fileName} арилгах",
    "Open this location in OpenStreetMap" : "Энэ байршлыг OpenStreetMap-д нээх",
    "_%n reply_::_%n replies_" : ["%n хариулт","%n хариулт"],
    "Sending message" : "Мессеж илгээж байна",
    "Failed to send the message. Click to try again" : "Мессеж илгээж чадсангүй. Дахин оролдохын тулд дарна уу",
    "Not enough free space to upload file" : "Файл байршуулах хангалттай зай байхгүй",
    "You cannot send messages to this conversation at the moment" : "Та одоогоор энэ яриад мессеж илгээх боломжгүй",
    "Could not update the message" : "Мессежийг шинэчлэж чадсангүй",
    "Reply to thread \"{threadTitle}\"" : "\"{threadTitle}\" хэлэлцүүлэгт хариулах",
    "_%n vote_::_%n votes_" : ["%n санал","%n санал"],
    "Edit poll draft" : "Санал асуулгын ноорог засах",
    "Delete poll draft" : "Санал асуулгын ноорог устгах",
    "Open poll" : "Санал асуулга нээх",
    "See results" : "Үр дүн харах",
    "Reactions" : "Хариу үйлдлүүд",
    "No permission to post reactions in this conversation" : "Энэ яриад хариу үйлдэл илгээх зөвшөөрөл байхгүй",
    "and {participant}" : "болон {participant}",
    "_and %n other participant_::_and %n other participants_" : ["болон %n бусад оролцогч","болон %n бусад оролцогч"],
    "Show all reactions" : "Бүх хариу үйлдлийг харуулах",
    "Add more reactions" : "Илүү олон хариу үйлдэл нэмэх",
    "Show or collapse system messages" : "Системийн мессежийг харуулах эсвэл хураах",
    "No messages" : "Мессеж байхгүй",
    "All messages have expired or have been deleted." : "Бүх мессеж дууссан эсвэл устгагдсан.",
    "{author} (pinned by you)" : "{author} (та бэхэлсэн)",
    "{author} (pinned by {actor})" : "{author} ({actor} бэхэлсэн)",
    "Unpin" : "Бэхлэлт авах",
    "Cancel search" : "Хайлт болих",
    "Add a phone number" : "Утасны дугаар нэмэх",
    "Error: A password is required to create the conversation." : "Алдаа: Яриа үүсгэхэд нууц үг шаардлагатай.",
    "All set, the conversation \"{conversationName}\" was created." : "Бүгд бэлэн, \"{conversationName}\" яриа үүсгэгдлээ.",
    "Create a new group conversation" : "Шинэ бүлгийн яриа үүсгэх",
    "Add participants" : "Оролцогчид нэмэх",
    "Maximum length exceeded ({maxlength} characters)" : "Хамгийн их урт хэтэрсэн ({maxlength} тэмдэгт)",
    "Conversation visibility" : "Ярианы харагдац",
    "Allow guests to join via link" : "Зочдод холбоосоор нэгдэхийг зөвшөөрөх",
    "Enter password" : "Нууц үг оруулах",
    "This conversation has been locked" : "Энэ яриа түгжигдсэн",
    "No permission to post messages in this conversation" : "Энэ яриад мессеж илгээх зөвшөөрөл байхгүй",
    "Write a message without notification" : "Мэдэгдэлгүй мессеж бичих",
    "Create a thread silently" : "Thread чимээгүй үүсгэх",
    "Create a thread" : "Thread үүсгэх",
    "Send message silently" : "Мессежийг чимээгүй илгээх",
    "Send message" : "Мессеж илгээх",
    "Send without notification" : "Мэдэгдэлгүй илгээх",
    "The participant will not be notified about new messages" : "Оролцогчид шинэ мессежийн талаар мэдэгдэхгүй",
    "Participants will not be notified about new messages" : "Оролцогчдод шинэ мессежийн талаар мэдэгдэхгүй",
    "Message will be sent {datetimeString}" : "Мессеж {datetimeString}-д илгээгдэнэ",
    "Thread title is required" : "Thread гарчиг шаардлагатай",
    "Message text is required" : "Мессежийн текст шаардлагатай",
    "The message could not be edited" : "Мессежийг засварлаж чадсангүй",
    "File to share" : "Хуваалцах файл",
    "File upload is not available in this conversation" : "Энэ яриад файл байршуулах боломжгүй",
    "Message was successfully scheduled" : "Мессеж амжилттай товлогдлоо",
    "Add emoji" : "Эможи нэмэх",
    "Adding a mention will only notify users who did not read the message." : "Дурдалт нэмэх нь зөвхөн мессежийг уншаагүй хэрэглэгчдэд мэдэгдэнэ.",
    "Thread title" : "Thread гарчиг",
    "Send later" : "Дараа илгээх",
    "Show scheduled messages" : "Товлогдсон мессежүүдийг харуулах",
    "Cancel editing" : "Засварлалт болих",
    "Schedule message" : "Мессеж товлох",
    "{user} is out of office and might not respond." : "{user} оффисоос гадуур байгаа тул хариулахгүй байж болно.",
    "Absence period: {startDate} - {endDate}" : "Эзгүй хугацаа: {startDate} - {endDate}",
    "Replacement:" : "Орлогч:",
    "Share from {nextcloud}" : "{nextcloud}-оос хуваалцах",
    "Share from Files" : "Файлуудаас хуваалцах",
    "Share files to the conversation" : "Яриад файлууд хуваалцах",
    "Upload from device" : "Төхөөрөмжөөс байршуулах",
    "Create new poll" : "Шинэ санал асуулга үүсгэх",
    "Smart picker" : "Ухаалаг сонгогч",
    "Record voice message" : "Дуут мессеж бичих",
    "End recording and send" : "Бичлэг дуусгаж илгээх",
    "Dismiss recording" : "Бичлэгийг хаях",
    "Access to the microphone was denied" : "Микрофонд хандах эрхийг татгалзлаа",
    "Microphone either not available or disabled in settings" : "Микрофон боломжгүй эсвэл тохиргоонд идэвхгүй болсон",
    "Error while recording audio" : "Аудио бичихэд алдаа гарлаа",
    "Summary is AI generated and might contain mistakes" : "Хураангуй нь AI-аар үүсгэгдсэн тул алдаа агуулж болзошгүй",
    "Error occurred during a summary generation" : "Хураангуй үүсгэхэд алдаа гарлаа",
    "New file" : "Шинэ файл",
    "Blank" : "Хоосон",
    "Error while creating file" : "Файл үүсгэхэд алдаа гарлаа",
    "Create and share a new file" : "Шинэ файл үүсгэж хуваалцах",
    "Name of the new file" : "Шинэ файлын нэр",
    "Create file" : "Файл үүсгэх",
    "Add more files" : "Илүү олон файл нэмэх",
    "Send" : "–∏–ª–≥—ç—ç—Ö",
    "In this conversation <strong>{user}</strong> can:" : "Энэ яриад <strong>{user}</strong> чадна:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "<strong>{conversationName}</strong> дахь оролцогчдын анхдагч зөвшөөрлүүдийг засварлах",
    "Start a call" : "Дуудлага эхлүүлэх",
    "Skip the lobby" : "Лоббийг алгасах",
    "Can post messages" : "Зурвас бичих боломжтой",
    "Can post messages and reactions" : "Мессеж болон хариу үйлдэл илгээх боломжтой",
    "Can add reactions" : "Хариу үйлдэл нэмэх боломжтой",
    "Enable the microphone" : "Микрофонийг идэвхжүүлэх",
    "Enable the camera" : "Камерыг идэвхжүүлэх",
    "Share the screen" : "Дэлгэцийг хуваалцах",
    "Update permissions" : "Зөвшөөрлүүдийг шинэчлэх",
    "Updating permissions" : "Зөвшөөрлүүдийг шинэчилж байна",
    "No poll drafts" : "Санал асуулгын ноорог байхгүй",
    "There is no poll drafts yet saved for this conversation" : "Энэ яриад санал асуулгын ноорог хадгалагдаагүй байна",
    "Create poll in {name}" : "{name}-д санал асуулга үүсгэх",
    "Create poll" : "Санал асуулга үүсгэх",
    "Error while importing poll" : "Санал асуулга импортлоход алдаа гарлаа",
    "Question" : "Асуулт",
    "Ask a question" : "Асуулт асуух",
    "Import draft from file" : "Файлаас ноорог импортлох",
    "Answers" : "Хариултууд",
    "Answer {option}" : "Хариулт {option}",
    "Delete poll option" : "Санал асуулгын сонголтыг устгах",
    "Add answer" : "Хариулт нэмэх",
    "Settings" : "–¢–æ—Ö–∏—Ä–≥–æ–æ",
    "Anonymous poll" : "Нэргүй санал асуулга",
    "Multiple answers" : "Олон хариулт",
    "Save as draft" : "Ноорог болгон хадгалах",
    "Export draft to file" : "Нооргийг файл руу экспортлох",
    "You voted for this option" : "Та энэ сонголтод санал өгсөн",
    "End poll" : "Санал асуулга дуусгах",
    "Change your vote" : "Санал өөрчлөх",
    "Results" : "“Æ—Ä –¥“Ø–Ω",
    "Voted participants" : "Санал өгсөн оролцогчид",
    "Send a message to \"{roomName}\"" : "\"{roomName}\" руу мессеж илгээх",
    "Hide list of participants" : "Оролцогчдын жагсаалтыг нуух",
    "Show list of participants" : "Оролцогчдын жагсаалтыг харуулах",
    "Assistance requested in {roomName}" : "{roomName}-д тусламж хүссэн",
    "The message was sent to \"{roomName}\"" : "Мессеж \"{roomName}\" руу илгээгдлээ",
    "Dismiss request for assistance" : "Тусламжийн хүсэлтийг хаях",
    "Send message to room" : "Өрөөнд мессеж илгээх",
    "Back to main room" : "Үндсэн өрөө рүү буцах",
    "Back to your room" : "Өөрийн өрөө рүү буцах",
    "Message all rooms" : "Бүх өрөөнд мессеж илгээх",
    "Start session" : "Сесс эхлүүлэх",
    "Start a call before you start a breakout room session" : "Салангид өрөөний сесс эхлүүлэхээс өмнө дуудлага эхлүүлнэ үү",
    "Stop session" : "Сесс зогсоох",
    "The message was sent to all breakout rooms" : "Мессеж бүх салангид өрөөнүүдэд илгээгдлээ",
    "Send a message to all breakout rooms" : "Бүх салангид өрөөнүүдэд мессеж илгээх",
    "Breakout rooms are not started" : "Салангид өрөөнүүд эхлээгүй",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Өндөр гүйцэтгэлтэй backend-гүй дуудлагууд холболтын асуудал болон төхөөрөмжүүдэд их ачаалал үүсгэж болно. {linkstart}Дэлгэрэнгүй{linkend}",
    "Talk setup incomplete" : "Talk тохиргоо дуусаагүй",
    "Disable lobby" : "Лоббийг идэвхгүй болгох",
    "Settings for participant \"{user}\"" : "\"{user}\" оролцогчийн тохиргоо",
    "Participant \"{user}\"" : "\"{user}\" оролцогч",
    "moderator" : "модератор",
    "bot" : "бот",
    "guest" : "зочин",
    "Call rejected" : "Дуудлага татгалзагдсан",
    "{time} talking time" : "{time} ярьсан хугацаа",
    "Raised their hand" : "Гараа өргөсөн",
    "Joined with video" : "Видеотой нэгдсэн",
    "Joined via phone" : "Утсаар нэгдсэн",
    "Joined with audio" : "Аудиотой нэгдсэн",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Текст {maxLength} тэмдэгтээс бага эсвэл тэнцүү байх ёстой. Таны одоогийн текст {charactersCount} тэмдэгт урттай.",
    "Remove group and members" : "Бүлэг болон гишүүдийг хасах",
    "Remove team and members" : "Баг болон гишүүдийг хасах",
    "Remove participant" : "Оролцогчийг хасах",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Та \"{displayName}\" бүлэг болон түүний гишүүдийг энэ яриаас устгахыг хүсэж байна уу?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Та \"{displayName}\" баг болон түүний гишүүдийг энэ яриаас устгахыг хүсэж байна уу?",
    "Do you really want to remove {displayName} from this conversation?" : "Та үнэхээр {displayName}-г энэ яриаас хасах уу?",
    "Notification was sent to {displayName}" : "Мэдэгдэл {displayName}-д илгээгдлээ",
    "Could not send notification to {displayName}" : "{displayName}-д мэдэгдэл илгээж чадсангүй",
    "Permissions granted to {displayName}" : "{displayName}-д зөвшөөрөл олгогдлоо",
    "Could not modify permissions for {displayName}" : "{displayName}-ийн зөвшөөрлийг өөрчлөх боломжгүй",
    "Permissions removed for {displayName}" : "{displayName}-ийн зөвшөөрлүүд хасагдлаа",
    "Permissions set to default for {displayName}" : "{displayName}-ийн зөвшөөрлүүд өгөгдмөл болгогдлоо",
    "Phone number could not be hung up" : "Утасны дугаарыг тасалж чадсангүй",
    "Phone number could not be put on hold" : "Утасны дугаарыг хүлээлгээнд оруулж чадсангүй",
    "Phone number could not be muted" : "Утасны дугаарыг хааж чадсангүй",
    "Phone number could not be unmuted" : "Утасны дугаарын хаалтыг нээж чадсангүй",
    "DTMF message could not be sent" : "DTMF мессежийг илгээж чадсангүй",
    "Phone number copied to clipboard" : "Утасны дугаар санах ойд хуулагдлаа",
    "Phone number could not be copied" : "Утасны дугаарыг хуулж чадсангүй",
    "in the lobby" : "лоббид",
    "Dial out phone" : "Утас руу залгах",
    "Hang up phone" : "Утас тасалах",
    "Move back to lobby" : "Лобби руу буцах",
    "Move to conversation" : "Яриа руу шилжих",
    "Dial-in PIN" : "Залгах PIN",
    "Demote from moderator" : "Модератораас буулгах",
    "Promote to moderator" : "Модератор болгох",
    "Resend invitation" : "Урилга дахин илгээх",
    "Send call notification" : "Дуудлагын мэдэгдэл илгээх",
    "Dial out phone number" : "Утасны дугаар руу залгах",
    "Resume call for phone number" : "Утасны дугаарын дуудлагыг үргэлжлүүлэх",
    "Put phone number on hold" : "Утасны дугаарыг хүлээлгэнд оруулах",
    "Unmute phone number" : "Утасны дугаарын хаалтыг нээх",
    "Mute phone number" : "Утасны дугаарыг хаах",
    "Copy phone number" : "Утасны дугаар хуулах",
    "Reset custom permissions" : "Тусгай зөвшөөрлүүдийг дахин тохируулах",
    "Grant all permissions" : "Бүх зөвшөөрөл олгох",
    "Remove all permissions" : "Бүх зөвшөөрлийг хасах",
    "Also ban from this conversation" : "Мөн энэ яриаг хориглох",
    "Internal note (reason to ban)" : "Дотоод тэмдэглэл (хориглосон шалтгаан)",
    "Remove" : "Хасах",
    "Permissions modified for {displayName}" : "{displayName}-ийн зөвшөөрлүүд өөрчлөгдлөө",
    "Add users, groups or teams" : "Хэрэглэгчид, бүлгүүд эсвэл багууд нэмэх",
    "Add users or groups" : "Add users or groups",
    "Add users or teams" : "Хэрэглэгчид эсвэл багууд нэмэх",
    "Add users" : "Хэрэглэгчид нэмэх",
    "Add groups or teams" : "Бүлгүүд эсвэл багууд нэмэх",
    "Add groups" : "Бүлгүүд нэмэх",
    "Add teams" : "Багууд нэмэх",
    "Add other sources" : "Бусад эх үүсвэрүүд нэмэх",
    "Add emails" : "Имэйлүүд нэмэх",
    "Integrations" : "Нэгтгэлүүд",
    "Add federated users" : "Федерацийн хэрэглэгчид нэмэх",
    "Searching …" : "Хайж байна …",
    "Search for more users" : "Илүү олон хэрэглэгч хайх",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Та нэр, и-мэйл эсвэл Холбогдсон Cloud ID-аар оролцогчдыг хайх эсвэл нэмж болно",
    "Search or add participants" : "Оролцогчдыг хайх эсвэл нэмэх",
    "Invitation was sent to {actorId}" : "Урилга {actorId}-д илгээгдлээ",
    "An error occurred while adding the participants" : "Оролцогчдыг нэмэхэд алдаа гарлаа",
    "A new group conversation with selected participant will be created" : "Сонгосон оролцогчтой шинэ бүлгийн яриа үүсгэгдэнэ",
    "Participants" : "Оролцогчид",
    "Pinned by a deleted user" : "Устгагдсан хэрэглэгч бэхэлсэн",
    "Participants ({count})" : "Оролцогчид ({count})",
    "Open chat" : "Чат нээх",
    "You have new unread messages in the chat." : "Чатад шинэ уншаагүй мессежүүд байна.",
    "You have been mentioned in the chat." : "Чатад таныг дурдсан.",
    "Search messages" : "Мессеж хайх",
    "Chat" : "Чат",
    "Details" : "–î—ç–ª–≥—ç—Ä—ç–Ω–≥“Ø–π",
    "Shared items" : "Хуваалцсан зүйлс",
    "Search in {name}" : "{name}-д хайх",
    "Threads in {name}" : "{name} дахь thread-үүд",
    "{actor} in {conversation}" : "{conversation} дахь {actor}",
    "Search options" : "Хайлтын сонголтууд",
    "From User" : "Хэрэглэгчээс",
    "Since" : "Хойш",
    "Until" : "Хүртэл",
    "No results found" : "Үр дүн олдсонгүй",
    "Load more results" : "Нэмэлт үр дүн ачаалах",
    "Recent threads" : "Сүүлийн thread-үүд",
    "Projects" : "Төслүүд",
    "No shared items" : "Хуваалцсан зүйлс байхгүй",
    "Thread notifications" : "Thread мэдэгдлүүд",
    "Thread actions" : "Thread үйлдлүүд",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Яриа руу холбоос",
    "No open conversations found" : "Нээлттэй яриа олдсонгүй",
    "Either there are no open conversations or you joined all of them." : "Нээлттэй яриа байхгүй эсвэл та бүгдэд нь нэгдсэн.",
    "Check spelling or use complete words." : "Зөв бичгийн дүрмийг шалгах эсвэл бүтэн үг ашиглана уу.",
    "Search conversations or users" : "Яриануудыг эсвэл хэрэглэгчдийг хайх",
    "Select conversation" : "Яриа сонгох",
    "Number length is not valid" : "Дугаарын урт буруу байна",
    "Region code is not valid" : "Бүсийн код буруу байна",
    "Number length is too short" : "Дугаарын урт хэт богино байна",
    "Number length is too long" : "Дугаарын урт хэт урт байна",
    "Number is not valid" : "Дугаар буруу байна",
    "Phone numbers" : "Утасны дугаарууд",
    "Display name: {name}" : "Дэлгэцийн нэр: {name}",
    "Edit display name" : "Дэлгэцийн нэр засах",
    "Display name (required)" : "Дэлгэцийн нэр (шаардлагатай)",
    "Save name" : "Нэр хадгалах",
    "I picked message bubbles" : "Би зурвасын бөмбөлгийг сонгосон",
    "Error while setting personal setting" : "Хувийн тохиргоог тохируулахад алдаа гарлаа",
    "Error while saving sounds setting" : "Дууны тохиргоог хадгалахад алдаа гарлаа",
    "Compact conversations list" : "Нягт ярианы жагсаалт",
    "Chat appearance" : "Чатын харагдах байдал",
    "Messages list" : "Зурвасын жагсаалт",
    "Message bubbles" : "Зурвасын бөмбөлөг",
    "Play sounds when participants join or leave a call" : "Оролцогчид дуудлагад нэгдэх эсвэл гарахад дуу тоглуулах",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Үйлдвэрлэгчийн техникийн хязгаарлалтаас шалтгаалан iPhone болон iPad дээр одоогоор боломжгүй",
    "Notification settings" : "Мэдэгдлийн тохиргоо",
    "Sounds for chat and call notifications" : "Чат болон дуудлагын мэдэгдлийн дуу",
    "Invalid language ({languageId})" : "Буруу хэл ({languageId})",
    "Default language" : "Өгөгдмөл хэл",
    "Default language ({languageName})" : "Өгөгдмөл хэл ({languageName})",
    "Error when trying to load the available live translation languages" : "Шууд орчуулгын боломжит хэлүүдийг ачаалахад алдаа гарлаа",
    "Error when trying to set live translation language" : "Шууд орчуулгын хэлийг тохируулахад алдаа гарлаа",
    "Set language used to show the transcriptions" : "Хуулбар текстийг харуулах хэлийг тохируулах",
    "Select location for attachments" : "Хавсралтуудын байршил сонгох",
    "Error while setting attachment folder" : "Хавсралтын хавтас тохируулахад алдаа гарлаа",
    "Error while setting read status privacy" : "Унших төлөвийн нууцлалыг тохируулахад алдаа гарлаа",
    "Error while setting typing status privacy" : "Бичиж байгаа төлөвийн нууцлалыг тохируулахад алдаа гарлаа",
    "Error while setting default media state" : "Өгөгдмөл медиа төлөвийг тохируулахад алдаа гарлаа",
    "Turn camera and microphone off by default" : "Камер болон микрофоныг өгөгдмөлөөр унтраах",
    "Blur camera background by default" : "Камерын дэвсгэрийг өгөгдмөлөөр бүдгэрүүлэх",
    "Skip device preview before joining a call" : "Дуудлагад нэгдэхээс өмнө төхөөрөмжийн урьдчилсан харагдацыг алгасах",
    "Appearance & Sounds" : "Гадаад төрх & Дуу",
    "Privacy" : "–•—É–≤–∏–π–Ω –Ω—É—É—Ü",
    "Send read receipts" : "Унших баталгаа илгээх",
    "When off, all read statuses will be hidden" : "Унтраасан үед бүх унших төлөвүүд нуугдана",
    "Share typing status" : "Бичиж байгаа төлөвийг хуваалцах",
    "When off, all typing indicators will be hidden" : "Унтраасан үед бүх бичиж байгаа заагч нуугдана",
    "Attachments folder" : "Хавсралтын хавтас",
    "Toggle full screen" : "Бүтэн дэлгэц сэлгэх",
    "Return to Home screen" : "Нүүр дэлгэц рүү буцах",
    "Search" : "–•–∞–π—Ö",
    "Shortcuts while in a chat" : "Чат дотор товчлолууд",
    "Focus the chat input" : "Чатын оролтод анхаарах",
    "Unfocus the chat input to use shortcuts" : "Товчлолуудыг ашиглахын тулд чатын оролтоос анхаарлаа холдуулах",
    "Edit your last message" : "Сүүлийн мессежээ засах",
    "Shortcuts while in a call" : "Дуудлага дотор товчлолууд",
    "Camera on and off" : "Камер асаах, унтраах",
    "Microphone on and off" : "Микрофон асаах, унтраах",
    "Raise or lower hand" : "Гар өргөх эсвэл буулгах",
    "Push to talk or push to mute" : "Ярихын тулд дарах эсвэл хаахын тулд дарах",
    "Zoom-in / zoom-out a screen share" : "Дэлгэц хуваалцалтыг томруулах / жижигрүүлэх",
    "Mouse wheel" : "Хулганы дугуй",
    "Start call silently" : "Дуудлагыг чимээгүй эхлүүлэх",
    "Start call" : "Дуудлага эхлүүлэх",
    "End call" : "Дуудлага дуусгах",
    "This call has just ended" : "Энэ дуудлага дөнгөж дууссан",
    "You will be able to join the call only after a moderator starts it." : "Модератор дуудлага эхлүүлсний дараа л та нэгдэх боломжтой.",
    "End call for everyone" : "Бүгдийн дуудлагыг дуусгах",
    "Starting the recording" : "Бичлэг эхлүүлж байна",
    "Recording" : "Бичлэг",
    "The call has been running for one hour." : "Дуудлага нэг цагийн турш үргэлжилж байна.",
    "Cancel recording start" : "Бичлэг эхлүүлэхийг болих",
    "Stop recording" : "Бичлэгийг зогсоох",
    "Send a reaction" : "Хариу үйлдэл илгээх",
    "React with {reaction}" : "{reaction}-аар хариу үзүүлэх",
    "All tasks done!" : "Бүх даалгавар дууслаа!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} / %n даалгавар","{done} / %n даалгавар"],
    "Add participants to this call" : "Энэ дуудлагад оролцогчид нэмэх",
    "_%n participant in call_::_%n participants in call_" : ["Дуудлагад %n оролцогч","Дуудлагад %n оролцогч"],
    "Scheduled messages" : "Товлосон мессежүүд",
    "You are not allowed to enable screensharing" : "Та дэлгэц хуваалцах эрхгүй байна",
    "No screensharing" : "Дэлгэц хуваалцахгүй",
    "Screensharing options" : "Дэлгэц хуваалцах сонголтууд",
    "Enable screensharing" : "Дэлгэц хуваалцахыг идэвхжүүлэх",
    "Bad sent video and screen quality." : "Видео болон дэлгэцийн чанар муу илгээгдэж байна.",
    "Bad sent screen quality." : "Дэлгэцийн чанар муу илгээгдэж байна.",
    "Bad sent video quality." : "Видеоны чанар муу илгээгдэж байна.",
    "Bad sent audio, video and screen quality." : "Аудио, видео болон дэлгэцийн чанар муу илгээгдэж байна.",
    "Bad sent audio and screen quality." : "Аудио болон дэлгэцийн чанар муу илгээгдэж байна.",
    "Bad sent audio and video quality." : "Аудио болон видеоны чанар муу илгээгдэж байна.",
    "Bad sent audio quality." : "Аудионы чанар муу илгээгдэж байна.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Таны интернэт холболт эсвэл компьютер завгүй байгаа тул бусад оролцогчид таны дэлгэцийг харах боломжгүй байж болно. Нөхцөлийг сайжруулахын тулд дэлгэц хуваалцаж байхдаа арын дэвсгэрийн бүдэгрүүлэлт эсвэл видеогоо идэвхгүй болго.",
    "Disable background blur" : "Дэвсгэр бүдгэрүүлэлтийг идэвхгүй болгох",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Таны интернэт холболт эсвэл компьютер завгүй байгаа тул бусад оролцогчид таны дэлгэцийг харах боломжгүй байж болно. Нөхцөлийг сайжруулахын тулд дэлгэц хуваалцаж байхдаа видеогоо идэвхгүй болго.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Таны интернэт холболт эсвэл компьютер завгүй байгаа тул бусад оролцогчид таны дэлгэцийг харах боломжгүй байж болно.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Таны интернэт холболт эсвэл компьютер завгүй байгаа тул бусад оролцогчид таныг харах боломжгүй байж болно.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Таны интернэт холболт эсвэл компьютер завгүй байгаа тул бусад оролцогчид таныг ойлгох болон харах боломжгүй байж болно. Нөхцөлийг сайжруулахын тулд дэлгэц хуваалцаж байхдаа арын дэвсгэрийн бүдэгрүүлэлт эсвэл видеогоо идэвхгүй болго.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Таны интернэт холболт эсвэл компьютер завгүй байгаа тул бусад оролцогчид таныг ойлгох болон харах боломжгүй байж болно. Нөхцөлийг сайжруулахын тулд дэлгэц хуваалцаж байхдаа видеогоо идэвхгүй болго.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Таны интернэт холболт эсвэл компьютер завгүй байгаа тул бусад оролцогчид таныг ойлгох болон дэлгэцийг тань харах боломжгүй байж болно. Нөхцөлийг сайжруулахын тулд дэлгэц хуваалцалтаа идэвхгүй болго.",
    "Disable screenshare" : "Дэлгэц хуваалцалтыг идэвхгүй болгох",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Таны интернэт холболт эсвэл компьютер завгүй байгаа тул бусад оролцогчид таныг ойлгох болон харах боломжгүй байж болно. Нөхцөлийг сайжруулахын тулд арын дэвсгэрийн бүдэгрүүлэлт эсвэл видеогоо идэвхгүй болго.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Таны интернэт холболт эсвэл компьютер завгүй байгаа тул бусад оролцогчид таныг ойлгох болон харах боломжгүй байж болно. Нөхцөлийг сайжруулахын тулд видеогоо идэвхгүй болго.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Таны интернэт холболт эсвэл компьютер завгүй байгаа тул бусад оролцогчид таныг ойлгох боломжгүй байж болно.",
    "Screen sharing is not supported by your browser." : "Таны хөтөч дэлгэц хуваалцахыг дэмжихгүй байна.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Дэлгэц хуваалцахад хуудас HTTPS-ээр ачаалагдсан байх шаардлагатай.",
    "Screensharing requires the page to be loaded through HTTPS." : "Дэлгэц хуваалцахад хуудас HTTPS-ээр ачаалагдсан байх шаардлагатай.",
    "An error occurred while starting screensharing." : "Дэлгэц хуваалцалт эхлүүлэхэд алдаа гарлаа.",
    "Select virtual background" : "Виртуал дэвсгэр сонгох",
    "Show your screen" : "Дэлгэцээ харуулах",
    "Stop screensharing" : "Дэлгэц хуваалцахаа зогсоох",
    "Mute others" : "Бусдыг хаах",
    "Start recording" : "Бичлэг эхлүүлэх",
    "Set up breakout rooms" : "Салангид өрөөнүүд тохируулах",
    "Download attendance list" : "Оролцооны жагсаалтыг татах",
    "Open Calendar" : "Календар нээх",
    "Remove participant {name}" : "{name} оролцогчийг хасах",
    "Would you like to delete this conversation?" : "Та энэ яриаг устгах уу?",
    "Are you sure you want to delete this conversation?" : "Та энэ яриаг устгахдаа итгэлтэй байна уу?",
    "Delete now" : "Одоо устгах",
    "Keep" : "Хадгалах",
    "Open dialpad" : "Дугаар цуглуулагч нээх",
    "Select a region" : "Бүс сонгох",
    "Local time: {time}" : "Орон нутгийн цаг: {time}",
    "Scheduled {datetime}" : "Товлосон {datetime}",
    "Scheduled for {datetime}" : "{datetime}-д товлосон",
    "Message without mention" : "Дурдалтгүй мессеж",
    "Mention myself" : "Өөрийгөө дурдах",
    "Mention everyone" : "Бүгдийг дурдах",
    "Select a conversation" : "Яриа сонгох",
    "Select a mode" : "Горим сонгох",
    "You do not have permissions to access this conversation." : "Танд энэ яриад хандах зөвшөөрөл байхгүй.",
    "Join a different conversation or start a new one." : "Өөр яриад нэгдэх эсвэл шинийг эхлүүлнэ үү.",
    "The conversation does not exist" : "Яриа байхгүй байна",
    "Join a conversation or start a new one!" : "Яриад нэгдэх эсвэл шинийг эхлүүлнэ үү!",
    "Duplicate session" : "Давхардсан сесс",
    "Creating and joining a conversation with \"{userid}\"" : "\"{userid}\"-тай яриа үүсгэж нэгдэж байна",
    "Join a conversation or start a new one" : "Яриад нэгдэх эсвэл шинийг эхлүүлнэ үү",
    "Error while joining the conversation" : "Яриад нэгдэхэд алдаа гарлаа",
    "Another user" : "Өөр хэрэглэгч",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud хэрэглэгч",
    "User password" : "Хэрэглэгчийн нууц үг",
    "Talk conversation" : "Talk —è—Ä–∏–∞",
    "Skip TLS verification" : "TLS баталгаажуулалтыг алгасах",
    "Matrix server URL" : "Matrix серверийн URL",
    "User" : "–•—ç—Ä—ç–≥–ª—ç–≥—á",
    "Matrix channel" : "Matrix суваг",
    "Mattermost server URL" : "Mattermost серверийн URL",
    "Mattermost user" : "Mattermost хэрэглэгч",
    "Team name" : "Багийн нэр",
    "Channel name" : "Сувгийн нэр",
    "Rocket.Chat server URL" : "Rocket.Chat серверийн URL",
    "User name or email address" : "Хэрэглэгчийн нэр эсвэл имэйл хаяг",
    "Rocket.Chat channel" : "Rocket.Chat суваг",
    "Zulip server URL" : "Zulip серверийн URL",
    "Bot user name" : "Ботын хэрэглэгчийн нэр",
    "Bot API key" : "Ботын API түлхүүр",
    "Zulip channel" : "Zulip суваг",
    "API token" : "API токен",
    "Slack channel" : "Slack суваг",
    "Server ID or name" : "Серверийн ID эсвэл нэр",
    "Channel ID (prefixed with \"ID:\") or name" : "Сувгийн ID (\"ID:\" угтвартай) эсвэл нэр",
    "Channel" : "–°—É–≤–∞–≥",
    "Login" : "–ù—ç–≤—Ç—Ä—ç—Ö",
    "Chat ID" : "Чат ID",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC серверийн URL (жнь. chat.freenode.net:6667)",
    "Nickname" : "–¢–æ–≤—á –Ω—ç—Ä",
    "Connection password" : "Холболтын нууц үг",
    "IRC channel" : "IRC суваг",
    "Channel password" : "Сувгийн нууц үг",
    "NickServ nickname" : "NickServ хоч",
    "NickServ password" : "NickServ нууц үг",
    "Use TLS" : "TLS ашиглах",
    "Use SASL" : "SASL ашиглах",
    "Tenant ID" : "Түрээслэгчийн ID",
    "Client ID" : "–•—ç—Ä—ç–≥–ª—ç–≥—á–∏–π–Ω ID",
    "Team ID" : "Багийн ID",
    "Thread ID" : "Thread ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber серверийн URL",
    "MUC server URL" : "MUC серверийн URL",
    "Jabber ID" : "Jabber ID",
    "Pinned messages" : "Бэхлэгдсэн мессежүүд",
    "Media" : "Медиа",
    "Polls" : "Санал асуулгууд",
    "Deck cards" : "Deck картууд",
    "Voice messages" : "Дуут мессежүүд",
    "Locations" : "Байршлууд",
    "Call recordings" : "Дуудлагын бичлэгүүд",
    "Audio" : "–ê—É–¥–∏–æ",
    "Show all pinned messages" : "Бүх бэхлэгдсэн мессежийг харуулах",
    "Show all media" : "Бүх медиаг харуулах",
    "Show all files" : "Бүх файлуудыг харуулах",
    "Show all polls" : "Бүх санал асуулгыг харуулах",
    "Show all deck cards" : "Бүх deck картуудыг харуулах",
    "Show all voice messages" : "Бүх дуут мессежийг харуулах",
    "Show all locations" : "Бүх байршлуудыг харуулах",
    "Show all call recordings" : "Бүх дуудлагын бичлэгийг харуулах",
    "Show all audio" : "Бүх аудиог харуулах",
    "Show all other" : "Бусад бүгдийг харуулах",
    "Follow conversation settings" : "Ярианы тохиргоог дагах",
    "Group" : "–ë“Ø–ª—ç–≥",
    "Team" : "Баг",
    "You reconnected to the call" : "Та дуудлагад дахин холбогдлоо",
    "{actor} reconnected to the call" : "{actor} дуудлагад дахин холбогдлоо",
    "You added {user0} and {user1}" : "Та {user0} болон {user1}-г нэмлээ",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Та {user0}, {user1} болон %n бусад оролцогчийг нэмсэн","Та {user0}, {user1} болон %n бусад оролцогчийг нэмсэн"],
    "An administrator added you and {user0}" : "Админ та болон {user0}-г нэмлээ",
    "{actor} added you and {user0}" : "{actor} та болон {user0}-г нэмлээ",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Админ та, {user0} болон %n бусад оролцогчийг нэмсэн","Админ та, {user0} болон %n бусад оролцогчийг нэмсэн"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} та, {user0} болон %n бусад оролцогчийг нэмсэн","{actor} та, {user0} болон %n бусад оролцогчийг нэмсэн"],
    "An administrator added {user0} and {user1}" : "Админ {user0} болон {user1}-г нэмлээ",
    "{actor} added {user0} and {user1}" : "{actor} {user0} болон {user1}-г нэмлээ",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Админ {user0}, {user1} болон %n бусад оролцогчийг нэмсэн","Админ {user0}, {user1} болон %n бусад оролцогчийг нэмсэн"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} {user0}, {user1} болон %n бусад оролцогчийг нэмсэн","{actor} {user0}, {user1} болон %n бусад оролцогчийг нэмсэн"],
    "You removed {user0} and {user1}" : "Та {user0} болон {user1}-г хаслаа",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Та {user0}, {user1} болон %n бусад оролцогчийг хассан","Та {user0}, {user1} болон %n бусад оролцогчийг хассан"],
    "An administrator removed you and {user0}" : "Админ та болон {user0}-г хаслаа",
    "{actor} removed you and {user0}" : "{actor} та болон {user0}-г хаслаа",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Админ та, {user0} болон %n бусад оролцогчийг хассан","Админ та, {user0} болон %n бусад оролцогчийг хассан"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} та, {user0} болон %n бусад оролцогчийг хассан","{actor} та, {user0} болон %n бусад оролцогчийг хассан"],
    "An administrator removed {user0} and {user1}" : "Админ {user0} болон {user1}-г хаслаа",
    "{actor} removed {user0} and {user1}" : "{actor} {user0} болон {user1}-г хаслаа",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Админ {user0}, {user1} болон %n бусад оролцогчийг хассан","Админ {user0}, {user1} болон %n бусад оролцогчийг хассан"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} {user0}, {user1} болон %n бусад оролцогчийг хассан","{actor} {user0}, {user1} болон %n бусад оролцогчийг хассан"],
    "You and {user0} joined the call" : "Та болон {user0} дуудлагад нэгдлээ",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Та, {user0} болон %n бусад оролцогч дуудлагад нэгдсэн","Та, {user0} болон %n бусад оролцогч дуудлагад нэгдсэн"],
    "{user0} and {user1} joined the call" : "{user0} болон {user1} дуудлагад нэгдлээ",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} болон %n бусад оролцогч дуудлагад нэгдсэн","{user0}, {user1} болон %n бусад оролцогч дуудлагад нэгдсэн"],
    "You and {user0} left the call" : "Та болон {user0} дуудлагаас гарлаа",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Та, {user0} болон %n бусад оролцогч дуудлагаас гарсан","Та, {user0} болон %n бусад оролцогч дуудлагаас гарсан"],
    "{user0} and {user1} left the call" : "{user0} болон {user1} дуудлагаас гарлаа",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} болон %n бусад оролцогч дуудлагаас гарсан","{user0}, {user1} болон %n бусад оролцогч дуудлагаас гарсан"],
    "You promoted {user0} and {user1} to moderators" : "Та {user0} болон {user1}-г модератор болгов",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Та {user0}, {user1} болон %n бусад оролцогчийг модератор болгосон","Та {user0}, {user1} болон %n бусад оролцогчийг модератор болгосон"],
    "An administrator promoted you and {user0} to moderators" : "Админ та болон {user0}-г модератор болгов",
    "{actor} promoted you and {user0} to moderators" : "{actor} та болон {user0}-г модератор болгов",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Админ та, {user0} болон %n нэмэлт оролцогчийг модератор болгон дэвшүүллээ","Админ та, {user0} болон %n нэмэлт оролцогчийг модератор болгон дэвшүүллээ"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} та, {user0} болон %n бусад оролцогчийг модератор болгосон","{actor} та, {user0} болон %n бусад оролцогчийг модератор болгосон"],
    "An administrator promoted {user0} and {user1} to moderators" : "Админ {user0} болон {user1}-г модератор болгов",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} {user0} болон {user1}-г модератор болгов",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Админ {user0}, {user1} болон %n нэмэлт оролцогчийг модератор болгон дэвшүүллээ","Админ {user0}, {user1} болон %n нэмэлт оролцогчийг модератор болгон дэвшүүллээ"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} нь {user0}, {user1} болон %n нэмэлт оролцогчийг модератор болгон дэвшүүллээ","{actor} нь {user0}, {user1} болон %n нэмэлт оролцогчийг модератор болгон дэвшүүллээ"],
    "You demoted {user0} and {user1} from moderators" : "Та {user0} болон {user1}-г модератораас буулгав",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Та {user0}, {user1} болон %n бусад оролцогчийг модератороос хассан","Та {user0}, {user1} болон %n бусад оролцогчийг модератороос хассан"],
    "An administrator demoted you and {user0} from moderators" : "Админ та болон {user0}-г модератораас буулгав",
    "{actor} demoted you and {user0} from moderators" : "{actor} та болон {user0}-г модератораас буулгав",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Админ та, {user0} болон %n нэмэлт оролцогчийг модераторын эрхээс хаслаа","Админ та, {user0} болон %n нэмэлт оролцогчийг модераторын эрхээс хаслаа"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} та, {user0} болон %n бусад оролцогчийг модератороос хассан","{actor} та, {user0} болон %n бусад оролцогчийг модератороос хассан"],
    "An administrator demoted {user0} and {user1} from moderators" : "Админ {user0} болон {user1}-г модератораас буулгав",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} {user0} болон {user1}-г модератораас буулгав",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Админ {user0}, {user1} болон %n нэмэлт оролцогчийг модераторын эрхээс хаслаа","Админ {user0}, {user1} болон %n нэмэлт оролцогчийг модераторын эрхээс хаслаа"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} нь {user0}, {user1} болон %n нэмэлт оролцогчийг модераторын эрхээс хаслаа","{actor} нь {user0}, {user1} болон %n нэмэлт оролцогчийг модераторын эрхээс хаслаа"],
    "You:" : "Та:",
    "You: {lastMessage}" : "Та: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(та засварласан)",
    "(edited by a deleted user)" : "(устгагдсан хэрэглэгч засварласан)",
    "(edited by {moderator})" : "({moderator} засварласан)",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Та өөр цонх эсвэл төхөөрөмж дээр идэвхтэй сесс байхад яриад нэгдэхийг оролдож байна. Nextcloud Talk одоогоор үүнийг дэмждэггүй. Та юу хийхийг хүсэж байна вэ?",
    "Leave this page" : "Энэ хуудаснаас гарах",
    "Join here" : "Энд нэгдэх",
    "Deck card has been posted to {conversation}" : "Deck карт {conversation} яриад илгээгдлээ",
    "An error occurred while posting deck card to conversation" : "Deck картыг яриад илгээхэд алдаа гарлаа",
    "Post to a conversation" : "Яриад илгээх",
    "Post to conversation" : "Яриад илгээх",
    "The recording failed. Please contact your administrator." : "Бичлэг амжилтгүй болсон. Админтайгаа холбогдоно уу.",
    "Location has been posted to {conversation}" : "Байршил {conversation} яриад илгээгдлээ",
    "An error occurred while posting location to conversation" : "Байршлыг яриад илгээхэд алдаа гарлаа",
    "Share to a conversation" : "Яриад хуваалцах",
    "Share to conversation" : "Яриад хуваалцах",
    "In conversation" : "Яриад",
    "Search in conversation: {conversation}" : "{conversation} яриад хайх",
    "Your requests are throttled at the moment due to brute force protection" : "Нэвтрэлтийн хүчний довтолгооноос хамгаалалтаас шалтгаалан таны хүсэлтүүд одоогоор хязгаарлагдсан",
    "Error while clearing conversation history" : "Ярианы түүхийг цэвэрлэхэд алдаа гарлаа",
    "Error occurred while allowing guests" : "Зочдыг зөвшөөрөхөд алдаа гарлаа",
    "Error occurred while disallowing guests" : "Зочдыг зөвшөөрөхгүй болгоход алдаа гарлаа",
    "Error occurred when restricting the conversation to moderator" : "Яриаг модераторт хязгаарлахад алдаа гарлаа",
    "Error occurred when opening the conversation to everyone" : "Яриаг бүх хүнд нээхэд алдаа гарлаа",
    "Conversation password has been saved" : "Ярианы нууц үг хадгалагдлаа",
    "Conversation password has been removed" : "Ярианы нууц үг арилгагдлаа",
    "Error occurred while saving conversation password" : "Ярианы нууц үг хадгалахад алдаа гарлаа",
    "Call recording is starting." : "Дуудлагын бичлэг эхэлж байна.",
    "Call recording stopped while starting." : "Дуудлагын бичлэг эхлэх үед зогссон.",
    "Call recording stopped. You will be notified once the recording is available." : "Дуудлагын бичлэг зогссон. Бичлэг бэлэн болмогц танд мэдэгдэнэ.",
    "Conversation picture set" : "Ярианы зураг тохируулагдлаа",
    "Conversation picture deleted" : "Ярианы зураг устгагдлаа",
    "Could not delete the conversation picture" : "Ярианы зургийг устгаж чадсангүй",
    "Could not remove the automatic expiration" : "Автомат дуусах хугацааг арилгаж чадсангүй",
    "Could not post message: {errorMessage}" : "Мессеж илгээж чадсангүй: {errorMessage}",
    "Participant is banned successfully" : "Оролцогч амжилттай хориглогдлоо",
    "Error while banning the participant" : "Оролцогчийг хориглоход алдаа гарлаа",
    "An error occurred while fetching the participants" : "Оролцогчдыг авахад алдаа гарлаа",
    "Could not send invitation to {actorId}" : "{actorId}-д урилга илгээж чадсангүй",
    "Invitations sent" : "Урилгууд илгээгдлээ",
    "Error occurred when sending invitations" : "Урилгууд илгээхэд алдаа гарлаа",
    "Failed to join the conversation." : "Яриад нэгдэж чадсангүй.",
    "An error occurred while creating breakout rooms" : "Салангид өрөөнүүд үүсгэхэд алдаа гарлаа",
    "An error occurred while re-ordering the attendees" : "Оролцогчдыг дахин эрэмбэлэхэд алдаа гарлаа",
    "An error occurred while deleting breakout rooms" : "Салангид өрөөнүүдийг устгахад алдаа гарлаа",
    "An error occurred while starting breakout rooms" : "Салангид өрөөнүүдийг эхлүүлэхэд алдаа гарлаа",
    "An error occurred while stopping breakout rooms" : "Салангид өрөөнүүдийг зогсооход алдаа гарлаа",
    "An error occurred while sending a message to the breakout rooms" : "Салангид өрөөнүүдэд мессеж илгээхэд алдаа гарлаа",
    "An error occurred while requesting assistance" : "Тусламж хүсэхэд алдаа гарлаа",
    "An error occurred while resetting the request for assistance" : "Тусламжийн хүсэлтийг дахин тохируулахад алдаа гарлаа",
    "An error occurred while joining breakout room" : "Салангид өрөөнд нэгдэхэд алдаа гарлаа",
    "Failed to rename the thread" : "Thread-ийн нэрийг өөрчилж чадсангүй",
    "Error fetching upcoming events" : "Удахгүй болох арга хэмжээнүүдийг авахад алдаа гарлаа",
    "Error fetching upcoming reminders" : "Удахгүй болох сануулгуудыг авахад алдаа гарлаа",
    "An error occurred while accepting an invitation" : "Урилга хүлээн авахад алдаа гарлаа",
    "An error occurred while rejecting an invitation" : "Урилгаас татгалзахад алдаа гарлаа",
    "{guest} (guest)" : "{guest} (зочин)",
    "Poll draft has been saved" : "Санал асуулгын ноорог хадгалагдлаа",
    "An error occurred while saving the draft" : "Ноорог хадгалахад алдаа гарлаа",
    "An error occurred while submitting your vote" : "Санал өгөхөд алдаа гарлаа",
    "An error occurred while ending the poll" : "Санал асуулга дуусгахад алдаа гарлаа",
    "An error occurred while deleting the poll draft" : "Санал асуулгын ноорог устгахад алдаа гарлаа",
    "Poll \"{name}\" was created by {user}. Click to vote" : "\"{name}\" санал асуулгыг {user} үүсгэсэн. Санал өгөхийн тулд дарна уу",
    "Failed to add reaction" : "Хариу үйлдэл нэмж чадсангүй",
    "Failed to remove reaction" : "Хариу үйлдэл арилгаж чадсангүй",
    "Error while uploading file \"{fileName}\"" : "\"{fileName}\" файлыг байршуулахад алдаа гарлаа",
    "Not enough free space to upload file \"{fileName}\"" : "\"{fileName}\" файлыг байршуулах хангалттай зай байхгүй",
    "You are not allowed to share files" : "Та файл хуваалцах эрхгүй байна",
    "Error while sharing file" : "Файл хуваалцахад алдаа гарлаа",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Таны ашиглаж буй хөтчийг Nextcloud Talk бүрэн дэмждэггүй. Mozilla Firefox, Microsoft Edge, Google Chrome, Opera эсвэл Apple Safari-ийн хамгийн сүүлийн хувилбарыг ашиглана уу.",
    "_In %n hour_::_In %n hours_" : ["%n цагийн дараа","%n цагийн дараа"],
    "_%n minute _::_%n minutes_" : ["%n минут ","%n минут"],
    "In {hours} and {minutes}" : "{hours} болон {minutes} дараа",
    "_In %n minute_::_In %n minutes_" : ["%n минутын дараа","%n минутын дараа"],
    "Set time for later today" : "Өнөөдөр дараа нь цаг тохируулах",
    "Set time for tomorrow" : "Маргааш цаг тохируулах",
    "Set time for this weekend" : "Энэ амралтын өдөр цаг тохируулах",
    "Set time for next week" : "Дараа долоо хоног цаг тохируулах",
    "Conversation link copied to clipboard" : "Ярианы холбоос санах ойд хуулагдлаа",
    "The link could not be copied" : "Холбоосыг хуулж чадсангүй",
    "Error while parsing a PROPFIND error" : "PROPFIND алдааг задлахад алдаа гарлаа",
    "Sending signaling message has failed" : "Signaling мессеж илгээж чадсангүй",
    "Lost connection to signaling server. Trying to reconnect." : "Signaling серверт холболт тасарлаа. Дахин холбогдож байна.",
    "Lost connection to signaling server." : "Signaling серверт холболт тасарлаа.",
    "Failed to connect. The signaling server may be set up incorrectly" : "Холбогдож чадсангүй. Дохионы сервер буруу тохируулагдсан байж магадгүй",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Тохируулагдсан дохионы серверийг Talk-ийн энэ хувилбартай нийцтэй болгохын тулд шинэчлэх шаардлагатай. Администрацитайгаа холбогдоно уу.",
    "Please restart the app." : "Апп-ийг дахин эхлүүлнэ үү.",
    "Please reload the page." : "–•—É—É–¥–∞—Å—ã–≥ –¥–∞—Ö–∏–Ω –∞—á–∞–∞–ª–Ω–∞ —É—É",
    "Please try to restart the app." : "Апп-ийг дахин эхлүүлж үзнэ үү.",
    "Please try to reload the page." : "Хуудсыг дахин ачаалж үзнэ үү.",
    "Do not disturb" : "–ë“Ø“Ø —Å–∞–∞–¥ –±–æ–ª",
    "Away" : "–•–æ–ª–¥—Å–æ–Ω",
    "Microphone {number}" : "Микрофон {number}",
    "Camera {number}" : "Камер {number}",
    "Speaker {number}" : "Чанга яригч {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Та дуугаа хааж байхдаа ярьж байх шиг байна, бусдад сонсогдохын тулд дуугаа нээнэ үү",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Дор хаяж нэг оролцогчтой холболт тогтоож чадсангүй. Таны нөхцөлд TURN сервер шаардлагатай байж магадгүй. {linkstart}энэ баримт бичиг{linkend}-ийг дагаж тохируулахыг администратораасаа хүснэ үү.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Энэ нь хүлээгдэж байснаас удаж байна. Медиа зөвшөөрлүүд аль хэдийн олгогдсон (эсвэл татгалзсан) уу? Хэрэв тийм бол хөтчөө дахин эхлүүлнэ үү, учир нь аудио болон видео алдаатай байна",
    "Access to microphone & camera is only possible with HTTPS" : "Микрофон болон камерт хандах нь зөвхөн HTTPS-ээр боломжтой",
    "Please move your setup to HTTPS" : "Тохиргоогоо HTTPS рүү шилжүүлнэ үү",
    "Access to microphone & camera was denied" : "Микрофон болон камерт хандах эрхийг татгалзлаа",
    "WebRTC is not supported in your browser" : "Таны хөтөч WebRTC дэмжихгүй",
    "Please use a different browser like Firefox or Chrome" : "Firefox эсвэл Chrome гэх мэт өөр хөтөч ашиглана уу",
    "Error while accessing microphone & camera" : "Микрофон болон камерт хандахад алдаа гарлаа",
    "%s Talk on your mobile devices" : "%s Talk таны гар утасны төхөөрөмжүүд дээр",
    "Join conversations at any time, anywhere, on any device." : "Хэзээ ч, хаана ч, ямар ч төхөөрөмж дээр яриануудад нэгдээрэй.",
    "Android app" : "Android апп",
    "iOS app" : "iOS апп",
    "__language_name__" : "__—Ö—ç–ª–Ω–∏–π_–Ω—ç—Ä__",
    "Webhook Demo" : "Webhook демо",
    "Call summary (%s)" : "–î—É—É–¥–ª–∞–≥—ã–Ω —Ö—É—Ä–∞–∞–Ω–≥—É–π (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Дуудлагын хураангуй бот дуудлагын дараа бүх оролцогчдыг жагсаасан болон даалгавруудыг тоймлосон мессеж оруулдаг",
    "Tasks" : "–î–∞–∞–ª–≥–∞–≤–∞—Ä",
    "Notes" : "–®–∏–Ω—ç ",
    "Reports" : "Тайлангууд",
    "Decisions" : "Шийдвэрүүд",
    "Agenda" : "Хөтөлбөр",
    "Call summary" : "Дуудлагын хураангуй",
    "Call summary - {title}" : "–î—É—É–¥–ª–∞–≥—ã–Ω —Ö—É—Ä–∞–∞–Ω–≥—É–π - {title}",
    "Talk conversation for event" : "Үйл явдлын Talk яриа",
    "Client Push is installed, this improves the performance of desktop clients." : "Client Push суулгагдсан, энэ нь ширээний клиентүүдийн гүйцэтгэлийг сайжруулна.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} суулгагдаагүй, энэ нь ширээний клиентүүд ашиглахад гүйцэтгэлийн асуудал үүсгэж болно.",
    "Next meeting" : "Дараагийн уулзалт",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Календараасаа уулзалт товло. Энд харуулахын тулд Talk яриаг байршлаар тохируулах шаардлагатай",
    "Join conversations from remote Nextcloud servers" : "Алсын Nextcloud серверүүдийн яриануудад нэгдэх",
    "Your default media state has been saved" : "Таны өгөгдмөл медиа төлөв хадгалагдлаа",
    "Set reminder for later today" : "Өнөөдөр дараа нь сануулга тохируулах",
    "Set reminder for tomorrow" : "Маргааш сануулга тохируулах",
    "Set reminder for this weekend" : "Энэ амралтын өдөр сануулга тохируулах",
    "Set reminder for next week" : "Дараа долоо хоног сануулга тохируулах",
    "Generate summary" : "Хураангуй үүсгэх",
    "Talk recording from {time} ({conversation})" : "Talk бичлэг {time}-д ({conversation})",
    "Submit vote" : "Санал өгөх",
    "Your privacy setting has been saved" : "Таны нууцлалын тохиргоо хадгалагдлаа",
    "Your personal setting has been saved" : "Таны хувийн тохиргоо хадгалагдлаа",
    "Failed to save sounds setting" : "Дууны тохиргоог хадгалж чадсангүй",
    "Sounds setting saved" : "Дууны тохиргоо хадгалагдлаа",
    "Always shown if recording consent is required" : "Бичлэгийн зөвшөөрөл шаардлагатай бол үргэлж харуулагдана",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk шинэчлэгдсэн, та дуудлага эхлүүлэх эсвэл нэгдэх боломжгүй.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Та өөр цонх эсвэл төхөөрөмжөөс яриад нэгдсэн. Nextcloud Talk одоогоор үүнийг дэмждэггүй тул энэ сессийг хаасан.",
    "Nextcloud Talk was updated." : "Nextcloud Talk шинэчлэгдлээ.",
    "Nextcloud is in maintenance mode." : "Nextcloud засвар үйлчилгээний горимд байна.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk Federation шинэчлэгдлээ.",
    "Enable live translation" : "Шууд орчуулгыг идэвхжүүлэх",
    "I picked list style" : "Би жагсаалт хэлбэрийг сонгосон",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Сайн уу! Та Talk-ыг жагсаалт хэлбэрээр ашиглаж байна уу, эсвэл зурвасын бөмбөлгөөр үү?"
},
"nplurals=2; plural=(n != 1);");
